@@ -49,8 +49,9 @@
 
 package com.openexchange.usm.api.database;
 
+import java.sql.Connection;
 import java.util.List;
-import com.openexchange.usm.api.exceptions.USMSQLException;
+import com.openexchange.usm.api.exceptions.USMStorageException;
 
 /**
  * Service that provides access to OX database or alternative database
@@ -66,18 +67,18 @@ public interface DatabaseAccess {
      * 
      * @param context
      * @return
-     * @throws DatabaseAccessException if the Connection can not be retrieved
+     * @throws StorageAccessException if the Connection can not be retrieved
      */
-    EncapsulatedConnection getWritable(int contextID) throws DatabaseAccessException;
+    EncapsulatedConnection getWritable(int contextID) throws StorageAccessException;
 
     /**
      * As getWritable(), but returns a Connection that can be used only for read access.
      * 
      * @param contextID
      * @return
-     * @throws DatabaseAccessException if the Connection can not be retrieved
+     * @throws StorageAccessException if the Connection can not be retrieved
      */
-    EncapsulatedConnection getReadOnly(int contextID) throws DatabaseAccessException;
+    EncapsulatedConnection getReadOnly(int contextID) throws StorageAccessException;
 
     /**
      * Generates a sequence in the database. Implementations can handle this differently depending on the database. (ex. create a table and
@@ -85,10 +86,10 @@ public interface DatabaseAccess {
      * 
      * @param contextID
      * @param sequenceName
-     * @throws USMSQLException if an error occurred while creating the sequence
-     * @throws DatabaseAccessException if the Connection can not be retrieved
+     * @throws USMStorageException if an error occurred while creating the sequence
+     * @throws StorageAccessException if the Connection can not be retrieved
      */
-    void generateSequence(int contextID, String sequenceName) throws USMSQLException, DatabaseAccessException;
+    void generateSequence(int contextID, String sequenceName) throws USMStorageException, StorageAccessException;
 
     /**
      * Gets the next id from a sequence in the database.
@@ -96,10 +97,10 @@ public interface DatabaseAccess {
      * @param contextID
      * @param sequenceName
      * @return
-     * @throws USMSQLException if an error occurred when retrieving the next id or no next id is returned
-     * @throws DatabaseAccessException if the Connection can not be retrieved
+     * @throws USMStorageException if an error occurred when retrieving the next id or no next id is returned
+     * @throws StorageAccessException if the Connection can not be retrieved
      */
-    int getNextIdFromSequence(int contextID, String sequenceName) throws USMSQLException, DatabaseAccessException;
+    int getNextIdFromSequence(int contextID, String sequenceName) throws USMStorageException, StorageAccessException;
 
     /**
      * Returns the name of the function used for retrieving a String representation of a hexadecimal value in the used DB.
@@ -117,19 +118,35 @@ public interface DatabaseAccess {
 
     /**
      * @return List of all currently available/used Context-IDs in the system
-     * @throws DatabaseAccessException if the list could not be generated/retrieved
+     * @throws StorageAccessException if the list could not be generated/retrieved
      */
-    List<Integer> getAllContextIds() throws DatabaseAccessException;
+    List<Integer> getAllContextIds() throws StorageAccessException;
 
     /**
      * @param contextId OX context-id
      * @return Array of all context-ids that are in the same schema as the given context-id
-     * @throws DatabaseAccessException if the array could not be generated/retrieved
+     * @throws StorageAccessException if the array could not be generated/retrieved
      */
-    int[] getContextsInSameSchema(int contextId) throws DatabaseAccessException;
+    int[] getContextsInSameSchema(int contextId) throws StorageAccessException;
     
     
     boolean supportsOnDuplicateKeyUpdateStatement();
     
     boolean supportsInsertIgnoreStatement();
+    
+    /**
+     * Releases a previously requested read/write SQL Connection so that it can be reused.
+     * 
+     * @param connection
+     * @throws StorageAccessException if an error occurred while releasing the Connection
+     */
+    void backWritable(int contextID, Connection connection) throws StorageAccessException;
+
+    /**
+     * Releases a previously requested read-only SQL Connection so that it can be reused.
+     * 
+     * @param connection
+     * @throws StorageAccessException if an error occurred while releasing the Connection
+     */
+    void backReadOnly(int contextID, Connection connection) throws StorageAccessException;
 }
