@@ -72,12 +72,12 @@ public class EncapsulatedConnection {
 	private final Connection _connection;
 	private final int _contextID;
 	private final boolean _readOnly;
-	private final SQLConnectionReleaser _releaser;
+	private final DatabaseAccess _dbAccess;
 	private boolean _closed = false;
 	private boolean _isAutoCommit = true;
 
-	public EncapsulatedConnection(SQLConnectionReleaser releaser, Connection connection, int contextID, boolean readOnly) {
-		_releaser = releaser;
+	public EncapsulatedConnection(DatabaseAccess dbAccess, Connection connection, int contextID, boolean readOnly) {
+		_dbAccess = dbAccess;
 		_connection = connection;
 		_contextID = contextID;
 		_readOnly = readOnly;
@@ -88,15 +88,15 @@ public class EncapsulatedConnection {
 		_connection.clearWarnings();
 	}
 
-	public void close() throws SQLException, DatabaseAccessException {
+	public void close() throws SQLException, StorageAccessException {
 		if (!_isAutoCommit)
 			throw new IllegalStateException("Closing connection while autoCommit==false");
 		checkNotClosed();
 		_closed = true;
 		if (_readOnly)
-			_releaser.backReadOnly(_contextID, _connection);
+		    _dbAccess.backReadOnly(_contextID, _connection);
 		else
-			_releaser.backWritable(_contextID, _connection);
+		    _dbAccess.backWritable(_contextID, _connection);
 	}
 
 	public void commit() throws SQLException {
@@ -155,7 +155,7 @@ public class EncapsulatedConnection {
 		return _connection.getWarnings();
 	}
 
-	public boolean isClosed() throws SQLException {
+	public boolean isClosed() {
 		return _closed;
 	}
 
