@@ -49,6 +49,7 @@
 
 package com.openexchange.usm.api.session;
 
+import java.io.Serializable;
 import java.util.BitSet;
 import java.util.Comparator;
 import java.util.Map;
@@ -56,14 +57,16 @@ import java.util.TimeZone;
 import java.util.UUID;
 import java.util.concurrent.locks.Lock;
 import org.json.JSONObject;
-import com.openexchange.usm.api.contenttypes.ContentType;
-import com.openexchange.usm.api.database.DatabaseAccessException;
-import com.openexchange.usm.api.database.EncapsulatedConnection;
+import com.openexchange.usm.api.contenttypes.common.ContentType;
+import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
 import com.openexchange.usm.api.exceptions.FolderNotFoundException;
 import com.openexchange.usm.api.exceptions.OXCommunicationException;
 import com.openexchange.usm.api.exceptions.USMException;
-import com.openexchange.usm.api.exceptions.USMSQLException;
+import com.openexchange.usm.api.exceptions.USMStorageException;
+import com.openexchange.usm.api.session.assets.ConflictResolution;
+import com.openexchange.usm.api.session.assets.SyncResult;
+import com.openexchange.usm.api.session.exceptions.SlowSyncRequiredException;
 
 /**
  * <h3>Session uniquely associated with user and device</h3> A Session provides methods that retrieve cached information for sync states and
@@ -83,7 +86,7 @@ import com.openexchange.usm.api.exceptions.USMSQLException;
  * 
  * @author afe
  */
-public interface Session {
+public interface Session extends Serializable {
 
     /**
      * Constant that can be used for all sync-calls that do not want to set any limit on the results
@@ -169,7 +172,7 @@ public interface Session {
      * @param name
      * @param value
      */
-    void setPersistentField(String name, String value) throws DatabaseAccessException, USMSQLException;
+    void setPersistentField(String name, String value) throws StorageAccessException, USMStorageException;
 
     /**
      * This method can be used to retrieve a previously stored custom property (which can be any Java Object) from the Session. The Property
@@ -346,16 +349,16 @@ public interface Session {
      * 
      * @param usedContentTypes Array of ContentTypes to use for this Session
      */
-    void setContentTypeFilter(ContentType... usedContentTypes) throws DatabaseAccessException, USMSQLException;
+    void setContentTypeFilter(ContentType... usedContentTypes) throws StorageAccessException, USMStorageException;
 
     /**
      * Returns all supported ContentTypes. Content types can be filtered out with the method setContentTypeFilter.
      * 
      * @return
-     * @throws DatabaseAccessException
-     * @throws USMSQLException
+     * @throws StorageAccessException
+     * @throws USMStorageException
      */
-    ContentType[] getContentTypes() throws DatabaseAccessException, USMSQLException;
+    ContentType[] getContentTypes() throws StorageAccessException, USMStorageException;
 
     /**
      * For each used ContentType a global filter can be specified that limits the fields to use for synchronization. Not all protocols
@@ -367,7 +370,7 @@ public interface Session {
      * @param contentType
      * @param fieldsOfInterest
      */
-    void setFieldFilter(ContentType contentType, String... fieldsOfInterest) throws DatabaseAccessException, USMSQLException;
+    void setFieldFilter(ContentType contentType, String... fieldsOfInterest) throws StorageAccessException, USMStorageException;
 
     /**
      * For each used ContentType a global filter can be specified that limits the fields to use for synchronization. Not all protocols
@@ -379,7 +382,7 @@ public interface Session {
      * @param contentType
      * @param fieldsOfInterest
      */
-    void setFieldFilter(ContentType contentType, BitSet fieldsOfInterest) throws DatabaseAccessException, USMSQLException;
+    void setFieldFilter(ContentType contentType, BitSet fieldsOfInterest) throws StorageAccessException, USMStorageException;
 
     /**
      * @param contentType
@@ -395,7 +398,7 @@ public interface Session {
      * 
      * @param resolution ConflictResolution to use for this Session
      */
-    void setConflictResolution(ConflictResolution resolution) throws DatabaseAccessException, USMSQLException;
+    void setConflictResolution(ConflictResolution resolution) throws StorageAccessException, USMStorageException;
 
     /**
      * <br>
@@ -591,7 +594,7 @@ public interface Session {
      * @param timestamp
      * @return
      */
-    Folder[] getCachedFolders(long timestamp) throws DatabaseAccessException, USMSQLException;
+    Folder[] getCachedFolders(long timestamp) throws StorageAccessException, USMStorageException;
 
     /**
      * Retrieves the cached folder for a given synchronization timestamp, if available. If the data is not (invalid timestamp) or no longer
@@ -601,7 +604,7 @@ public interface Session {
      * @param timestamp
      * @return
      */
-    Folder getCachedFolder(String folderId, long timestamp) throws DatabaseAccessException, USMSQLException;
+    Folder getCachedFolder(String folderId, long timestamp) throws StorageAccessException, USMStorageException;
 
     /**
      * Retrieves the cached elements of the given Folder for a given synchronization timestamp, if available. If the data is not (invalid
@@ -617,7 +620,7 @@ public interface Session {
      * @return
      * @throws IllegalArgumentException
      */
-    DataObject[] getCachedFolderElements(String folderId, ContentType elementsType, long timestamp) throws DatabaseAccessException, USMSQLException;
+    DataObject[] getCachedFolderElements(String folderId, ContentType elementsType, long timestamp) throws StorageAccessException, USMStorageException;
 
     /**
      * Retrieves the cached elements of the given Folder for a given synchronization timestamp, if available. If the data is not (invalid
@@ -635,7 +638,7 @@ public interface Session {
      * @return
      * @throws IllegalArgumentException
      */
-    DataObject getCachedFolderElement(String folderId, ContentType elementsType, String objectId, long timestamp) throws DatabaseAccessException, USMSQLException;
+    DataObject getCachedFolderElement(String folderId, ContentType elementsType, String objectId, long timestamp) throws StorageAccessException, USMStorageException;
 
     /**
      * Retrieves the most recent cached folder hierarchy, if available. If the data is not (no sync) or no longer available, this method
@@ -644,7 +647,7 @@ public interface Session {
      * @param timestamp
      * @return
      */
-    Folder[] getCachedFolders() throws DatabaseAccessException, USMSQLException;
+    Folder[] getCachedFolders() throws StorageAccessException, USMStorageException;
 
     /**
      * Retrieves the most recent cached folder, if available. If the data is not (no sync yet performed) or no longer available, this method
@@ -654,7 +657,7 @@ public interface Session {
      * @param timestamp
      * @return
      */
-    Folder getCachedFolder(String folderId) throws DatabaseAccessException, USMSQLException;
+    Folder getCachedFolder(String folderId) throws StorageAccessException, USMStorageException;
 
     /**
      * Retrieves the most recent cached elements of the given Folder, if available. If the data is not (no sync yet performed) or no longer
@@ -670,7 +673,7 @@ public interface Session {
      * @return
      * @throws IllegalArgumentException
      */
-    DataObject[] getCachedFolderElements(String folderId, ContentType elementsType) throws DatabaseAccessException, USMSQLException;
+    DataObject[] getCachedFolderElements(String folderId, ContentType elementsType) throws StorageAccessException, USMStorageException;
 
     /**
      * Retrieves the most recent cached element of the given Folder, if available. If the data is not (no sync yet performed) or no longer
@@ -687,7 +690,7 @@ public interface Session {
      * @return
      * @throws IllegalArgumentException
      */
-    DataObject getCachedFolderElement(String folderId, ContentType elementsType, String objectId) throws DatabaseAccessException, USMSQLException;
+    DataObject getCachedFolderElement(String folderId, ContentType elementsType, String objectId) throws StorageAccessException, USMStorageException;
 
     /**
      * Writes updates on 1 or more DataObjects to the Server. <br>
@@ -767,57 +770,49 @@ public interface Session {
      * 
      * @return String that contains all information to uniquely identify the persistent session
      */
+    @Override
     String toString();
 
     /**
-     * Returns an EncapsulatedConnection that can be used to access the DB. The Connection must be closed after usage. All used statements
-     * must be closed before closing the DB connection or their changes will be undone. If only reads on the database are performed, use
-     * getReadOnlyDBConnection() instead to improve DB performance. The Connection must be in state autocommit==true when it gets closed,
-     * otherwise an IllegalStateException will be thrown when attempting to close it.
-     * 
-     * @return EncapsulatedConnection that can be used to gain writable access to the DB for the user of this Session
-     * @throws DatabaseAccessException if an error occurs while retrieving the Connection
-     */
-    EncapsulatedConnection getWritableDBConnection() throws DatabaseAccessException;
-
-    /**
-     * Returns an EncapsulatedConnection that can be used to access the DB. The Connection must be closed after usage. All used statements
-     * must be closed before closing the DB connection or their changes will be undone. The returned Connection can be used only for
-     * read-only access, if any changes to the data might be required, use getWritableDBConnection() instead. The Connection must be in
-     * state autocommit==true when it gets closed, otherwise an IllegalStateException will be thrown when attempting to close it.
-     * 
-     * @return EncapsulatedConnection that can be used to gain read-only access to the DB for the user of this Session
-     * @throws DatabaseAccessException if an error occurs while retrieving the Connection
-     */
-    EncapsulatedConnection getReadOnlyDBConnection() throws DatabaseAccessException;
-
-    /**
-     * Maps the OX Folder ID to internal USM ID (short id). This mapping is stored in a db.
+     * Maps the OX Folder ID to internal USM ID (short id). This mapping is stored in a db, since 7.6.0 the folders UUID is used as a mapped ID for long folder IDs.
+     * Same as getShortFolderID(folderID, null).
      * 
      * @param folderID
      * @return USM folder ID
-     * @throws DatabaseAccessException if the database can not be accessed.
-     * @throws USMSQLException if some problems occur while saving the folder id in the database or retrieving the next usm short id from
-     *             the database.
+     * @throws StorageAccessException if the database can not be accessed.
+     * @throws USMStorageException if some problems occur while saving the folder id in the database or retrieving the next usm short id
+     *             from the database.
      */
-    String getShortFolderID(String folderID) throws DatabaseAccessException, USMSQLException;
+    String getShortFolderID(String folderID) throws StorageAccessException, USMStorageException;
 
+    /**
+     * Maps the OX folder ID to an internal USM ID (short id). If the folder id is long, no DB entry is found and the UUID is provided as second parameter, then that
+     * UUID is used for the mapping, otherwise the folder hierarchy cache is searched for a matching folder.
+     * 
+     * @param folderID
+     * @param folderUUID
+     * @return
+     * @throws StorageAccessException
+     * @throws USMStorageException
+     */
+    String getShortFolderID(String folderID, UUID folderUUID) throws StorageAccessException, USMStorageException;
+    
     /**
      * Gets the original OX Folder ID that is mapped to USM ID (shortFolderId).
      * 
      * @param shortFolderID
      * @return OX folder ID
-     * @throws USMSQLException if some problems occur while retrieving the folder id from the database.
+     * @throws USMStorageException if some problems occur while retrieving the folder id from the database.
      */
-    String getFolderID(String shortFolderID) throws USMSQLException;
+    String getFolderID(String shortFolderID) throws USMStorageException;
 
     /**
      * Ends the synchronization between client and server. This means deleting all persistent and cached data for a session from the DB.
      * 
-     * @throws USMSQLException if some problems occur while deleting data.
-     * @throws DatabaseAccessException if the database can not be accessed
+     * @throws USMStorageException if some problems occur while deleting data.
+     * @throws StorageAccessException if the database can not be accessed
      */
-    void endSyncronization() throws USMSQLException, DatabaseAccessException;
+    void endSyncronization() throws USMStorageException, StorageAccessException;
 
     /**
      * Locates a folder by its ID, either by searching it in the FolderHierarchy cache (if available), or by directly requesting the Folder
@@ -831,17 +826,42 @@ public interface Session {
      */
     Folder findFolder(String folderID) throws USMException;
 
-    void storeUUID(ContentType contentType, int objectId, UUID uuid, int folderOwner) throws USMException;
+    /**
+     * Retrieves the OX Object ID based on a known UUID for a data object.
+     * 
+     * @param contentType
+     * @param uuid
+     * @param folderID
+     * @return
+     * @throws USMException
+     */
+    String getMappedObjectId(ContentType contentType, UUID uuid, String parentFolderID) throws USMException;
 
-    UUID getUUID(ContentType contentType, int objectId) throws USMException;
+    /**
+     * Returns UUID for the context. This value is saved in a table UUIDHeader.
+     * 
+     * @return
+     * @throws StorageAccessException
+     * @throws USMStorageException
+     */
+    UUID getContextUUID() throws StorageAccessException, USMStorageException;
 
-    int getMappedObjectId(ContentType contentType, UUID uuid) throws USMException;
+    /**
+     * Retrieves a UUID for the object identified with context, id and parent folder. The UUID is taken from the last known sync state, or
+     * generated as new if not existing.
+     * 
+     * @param contentType
+     * @param objectId
+     * @return
+     * @throws StorageAccessException
+     * @throws USMStorageException
+     */
+    UUID getUUID(ContentType contentType, String objectId) throws StorageAccessException, USMStorageException;
 
-    UUID getContextUUID() throws DatabaseAccessException, USMSQLException;
-
-    void insertStoredUUID(DataObject o) throws DatabaseAccessException, USMSQLException;
-
-    void remapCachedData(String oldObjectID, String newObjectID) throws DatabaseAccessException, USMSQLException;;
+    /**
+     * Remaps the saved sync states for the object to the new object id.
+     */
+    void remapCachedData(String oldObjectID, String newObjectID) throws StorageAccessException, USMStorageException;
 
     /**
      * This method is deprecated, use getCachedFolder(contentType.getID()) instead
