@@ -51,33 +51,33 @@ package com.openexchange.usm.contenttypes.groups.impl;
 import java.util.BitSet;
 import java.util.HashMap;
 import java.util.Map;
-import org.apache.commons.logging.Log;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-import com.openexchange.usm.api.contenttypes.ContentType;
-import com.openexchange.usm.api.contenttypes.ContentTypeField;
-import com.openexchange.usm.api.contenttypes.OXFolderContent;
-import com.openexchange.usm.api.contenttypes.UnsupportedContentOperationException;
+import com.openexchange.usm.api.contenttypes.common.CommonConstants;
+import com.openexchange.usm.api.contenttypes.common.ContentType;
+import com.openexchange.usm.api.contenttypes.common.ContentTypeField;
+import com.openexchange.usm.api.contenttypes.folder.OXFolderContent;
+import com.openexchange.usm.api.contenttypes.groups.GroupsConstants;
 import com.openexchange.usm.api.exceptions.InternalUSMException;
 import com.openexchange.usm.api.exceptions.USMException;
+import com.openexchange.usm.api.exceptions.UnsupportedContentOperationException;
+import com.openexchange.usm.api.ox.json.JSONResult;
+import com.openexchange.usm.api.ox.json.JSONResultType;
+import com.openexchange.usm.api.ox.json.OXJSONAccess;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.contenttypes.util.AbstractTransferHandler;
-import com.openexchange.usm.contenttypes.util.UtilConstants;
-import com.openexchange.usm.ox_json.JSONResult;
-import com.openexchange.usm.ox_json.JSONResultType;
-import com.openexchange.usm.ox_json.OXJSONAccess;
 
 public class GroupsContentTypeTransferHandler extends AbstractTransferHandler {
 
 	private static final String WILDCARD_ALL = "*";
 	private static final String PATTERN = "pattern";
 
-	protected GroupsContentTypeTransferHandler(ContentType contentType, Log journal, OXJSONAccess ajaxAccess) {
-		super(contentType, journal, ajaxAccess);
+	public GroupsContentTypeTransferHandler(ContentType contentType, OXJSONAccess ajaxAccess) {
+		super(contentType, ajaxAccess);
 	}
 
 	@Override
@@ -87,24 +87,24 @@ public class GroupsContentTypeTransferHandler extends AbstractTransferHandler {
 
 	@Override
 	public void writeNewDataObject(DataObject object) throws USMException {
-		if (_journal.isErrorEnabled())
-			_journal.error(object.getSession() + " Creating a group is not supported");
+		if (LOG.isErrorEnabled())
+			LOG.error(object.getSession() + " Creating a group is not supported");
 		throw new UnsupportedContentOperationException(USMContentTypesGroupsErrorCodes.CREATE_ERROR,
 				"Creating a group is not supported");
 	}
 
 	@Override
 	public void writeUpdatedDataObject(DataObject object, long timestamp) throws USMException {
-		if (_journal.isErrorEnabled())
-			_journal.error(object.getSession() + " Updating a group is not supported");
+		if (LOG.isErrorEnabled())
+			LOG.error(object.getSession() + " Updating a group is not supported");
 		throw new UnsupportedContentOperationException(USMContentTypesGroupsErrorCodes.UPDATE_ERROR,
 				"Updating a group is not supported");
 	}
 
 	@Override
 	public void writeDeletedDataObject(DataObject object) throws USMException {
-		if (_journal.isErrorEnabled())
-			_journal.error(object.getSession() + " Deleting a group is not supported");
+		if (LOG.isErrorEnabled())
+			LOG.error(object.getSession() + " Deleting a group is not supported");
 		throw new UnsupportedContentOperationException(USMContentTypesGroupsErrorCodes.DELETE_ERROR,
 				"Deleting a group is not supported");
 	}
@@ -112,8 +112,8 @@ public class GroupsContentTypeTransferHandler extends AbstractTransferHandler {
 	@Override
 	public DataObject[] readUpdatedFolderContent(Folder folder, BitSet requestedFields, long timestamp)
 			throws USMException {
-		if (_journal.isErrorEnabled())
-			_journal.error(folder.getSession() + " Updating a folder content is not supported for groups");
+		if (LOG.isErrorEnabled())
+			LOG.error(folder.getSession() + " Updating a folder content is not supported for groups");
 		throw new UnsupportedContentOperationException(USMContentTypesGroupsErrorCodes.UPDATE_FOLDER_ERROR,
 				"Updating a folder content is not supported for groups");
 	}
@@ -126,8 +126,8 @@ public class GroupsContentTypeTransferHandler extends AbstractTransferHandler {
 	@Override
 	public DataObject[] readFolderContent(Folder folder, BitSet requestedFields) throws USMException {
 		Session session = folder.getSession();
-		if (_journal.isDebugEnabled())
-			_journal.debug(session + " Read all " + _contentType.getID());
+		if (LOG.isDebugEnabled())
+			LOG.debug(session + " Read all " + _contentType.getID());
 		Map<String, String> parameters = new HashMap<String, String>();
 		JSONObject requestBody = new JSONObject();
 		try {
@@ -136,10 +136,10 @@ public class GroupsContentTypeTransferHandler extends AbstractTransferHandler {
 			throw new InternalUSMException(USMContentTypesGroupsErrorCodes.READ_ALL_JSON_ERROR_1,
 					"Can not create request body for searching groups", e);
 		}
-		JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_SEARCH, session, parameters,
+		JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), CommonConstants.ACTION_SEARCH, session, parameters,
 				requestBody);
 		checkResult(result, JSONResultType.JSONObject);
-		long timestamp = result.getJSONObject().optLong(UtilConstants.TIMESTAMP, System.currentTimeMillis());
+		long timestamp = result.getJSONObject().optLong(CommonConstants.TIMESTAMP, System.currentTimeMillis());
 		JSONArray groupsArray = extractArrayResult(result);
 		DataObject[] resultArray = new DataObject[groupsArray.length()];
 		try {
