@@ -57,11 +57,12 @@ import static com.openexchange.usm.api.datatypes.DataTypes.TIME;
 import java.util.BitSet;
 import java.util.List;
 import org.json.JSONObject;
-import com.openexchange.usm.api.contenttypes.ContentTypeField;
-import com.openexchange.usm.api.contenttypes.ContentTypeTransferHandler;
-import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
-import com.openexchange.usm.api.contenttypes.MailContentType;
-import com.openexchange.usm.api.contenttypes.ResourceInputStream;
+import com.openexchange.usm.api.contenttypes.common.ContentTypeField;
+import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.mail.MailConstants;
+import com.openexchange.usm.api.contenttypes.mail.MailContentType;
+import com.openexchange.usm.api.contenttypes.resource.ResourceInputStream;
+import com.openexchange.usm.api.contenttypes.transferhandlers.ContentTypeTransferHandler;
 import com.openexchange.usm.api.datatypes.ArrayDataType;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.io.InputStreamProvider;
@@ -118,20 +119,17 @@ public class MailContentTypeImpl extends AbstractContentType implements MailCont
 
     private MailContentTypeTransferHandlerImpl _transferHandler;
 
-    /**
-     * Constructor is package private to discourage access from outside the bundle (but to allow usage in test cases)
-     */
-    MailContentTypeImpl() {
-    }
-
+    @Override
     public ContentTypeField[] getFields() {
         return FIELDS;
     }
 
+    @Override
     public String getID() {
         return DefaultContentTypes.MAIL_ID;
     }
 
+    @Override
     public ContentTypeTransferHandler getTransferHandler() {
         return _transferHandler;
     }
@@ -156,94 +154,117 @@ public class MailContentTypeImpl extends AbstractContentType implements MailCont
         return true;
     }
 
+    @Override
     public DataObject getReplyForward(Session session, String messageID, String folderID, String action, String view, boolean dropPrefix) throws USMException {
         return _transferHandler.getReplyForward(session, messageID, folderID, action, view, dropPrefix);
     }
 
+    @Override
     public byte[] readMailSource(DataObject object, BitSet requestedFields) throws USMException {
         return _transferHandler.readMailSource(object, requestedFields, false);
     }
 
+    @Override
     public void sendMail(String mail, Session session) throws USMException {
         _transferHandler.sendMail(mail, session);
     }
 
+    @Override
     public void sendMail(InputStreamProvider streamProvider, Session session) throws USMException {
         _transferHandler.sendMail(streamProvider, session);
     }
 
+    @Override
     public String createNewMail(String folderId, int flag, String mailMIMEdataBlock, Session session) throws USMException {
         return _transferHandler.createNewMail(folderId, flag, mailMIMEdataBlock, session);
     }
 
+    @Override
     public String createNewMailFromStream(String parentFolderID, int flags, InputStreamProvider streamProvider, Session session) throws USMException {
         return _transferHandler.createNewMailFromStream(parentFolderID, flags, streamProvider, session);
     }
 
+    @Override
     public Object getMailAttachment(Session session, String folderId, String mailId, String attachmentId) throws USMException {
         return _transferHandler.getMailAttachment(session, folderId, mailId, attachmentId);
     }
 
+    @Override
     public ResourceInputStream getMailAttachmentAsStream(Session session, String folderId, String mailId, String attachmentId) throws USMException {
         return _transferHandler.getMailAttachmentAsStream(session, folderId, mailId, attachmentId);
     }
 
+    @Override
     public int getCode() {
         return DefaultContentTypes.MAIL_CODE;
     }
 
+    @Override
     public JSONObject readStructuredMail(DataObject object, int maxAttachmentSize) throws USMException {
         return _transferHandler.readStructuredMail(object, maxAttachmentSize);
     }
 
+    @Override
     public boolean supportsPIMAttachments() {
         return false;
     }
 
+    @Override
     public Object getObjectGroupOwner(DataObject object) {
         return object.getID();
     }
 
+    @Override
     public JSONObject convertICalToJSON(DataObject mailObject, String attSeqId, String timezone) throws USMException {
         return _transferHandler.convertICalToJSON(mailObject, attSeqId, timezone);
     }
 
+    @Override
     public JSONObject analyzeICalAttachment(DataObject mailObject, String attSeqId) throws USMException {
         return _transferHandler.analyzeICalAttachment(mailObject, attSeqId);
     }
 
+    @Override
     public byte[] readMailSource(DataObject object, BitSet requestedFields, boolean ignoreICalAttachments) throws USMException {
         return _transferHandler.readMailSource(object, requestedFields, ignoreICalAttachments);
     }
 
+    @Override
     public JSONObject respondToMeetingRequest(DataObject mailObject, String attSeqId, int confirmation) throws USMException {
         return _transferHandler.respondToMeetingRequest(mailObject, attSeqId, confirmation);
     }
 
+    @Override
     public JSONObject updateObjectBasedOnMeetingRequest(DataObject mailObject, String attSeqId, String action) throws USMException {
         return _transferHandler.updateObjectBasedOnMeetingRequest(mailObject, attSeqId, action);
     }
 
+    @Override
     public List<DataObject> searchMails(JSONObject searchCriteria, String folderId, Session session, BitSet requestedFields) throws USMException {
         return _transferHandler.searchMails(searchCriteria, folderId, session, requestedFields);
     }
 
+    @Override
     public List<DataObject> searchMails(String searchText, String folderId, Session session, BitSet requestedFields) throws USMException {
         return _transferHandler.searchMails(searchText, folderId, session, requestedFields);
     }
 
+    @Override
     public JSONObject getVacationRule(Session session) throws USMException {
         return _transferHandler.getVacationRule(session);
     }
 
+    @Override
     public void setVacationRule(Session session, JSONObject rule) throws USMException {
         _transferHandler.setVacationRule(session, rule);
     }
 
+    @Override
     public void updateVacationRule(Session session, JSONObject rule) throws USMException {
         _transferHandler.updateVacationRule(session, rule);
     }
 
+    @Override
     public void deleteVacationRule(Session session, JSONObject rule) throws USMException {
         _transferHandler.deleteVacationRule(session, rule);
     }
