@@ -55,36 +55,36 @@ import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import org.apache.commons.logging.Log;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-import com.openexchange.usm.api.contenttypes.ContentType;
-import com.openexchange.usm.api.contenttypes.ContentTypeField;
-import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
-import com.openexchange.usm.api.contenttypes.MailContentType;
-import com.openexchange.usm.api.contenttypes.OXFolderContent;
-import com.openexchange.usm.api.contenttypes.ResourceInputStream;
-import com.openexchange.usm.api.contenttypes.UnsupportedContentOperationException;
+import com.openexchange.usm.api.contenttypes.common.CommonConstants;
+import com.openexchange.usm.api.contenttypes.common.ContentType;
+import com.openexchange.usm.api.contenttypes.common.ContentTypeField;
+import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.folder.OXFolderContent;
+import com.openexchange.usm.api.contenttypes.mail.MailConstants;
+import com.openexchange.usm.api.contenttypes.mail.MailContentType;
+import com.openexchange.usm.api.contenttypes.resource.ResourceInputStream;
 import com.openexchange.usm.api.exceptions.InternalUSMException;
 import com.openexchange.usm.api.exceptions.OXCommunicationException;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.exceptions.USMIllegalArgumentException;
 import com.openexchange.usm.api.exceptions.USMStartupException;
+import com.openexchange.usm.api.exceptions.UnsupportedContentOperationException;
 import com.openexchange.usm.api.io.InputStreamProvider;
+import com.openexchange.usm.api.ox.json.JSONResult;
+import com.openexchange.usm.api.ox.json.JSONResultType;
+import com.openexchange.usm.api.ox.json.OXJSONAccess;
+import com.openexchange.usm.api.ox.json.OXResource;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.api.session.Session;
-import com.openexchange.usm.api.session.SyncResult;
+import com.openexchange.usm.api.session.assets.SyncResult;
 import com.openexchange.usm.contenttypes.util.AbstractTransferHandler;
 import com.openexchange.usm.contenttypes.util.USMContentTypesUtilErrorCodes;
-import com.openexchange.usm.contenttypes.util.UtilConstants;
 import com.openexchange.usm.datatypes.mail.Vacation;
-import com.openexchange.usm.ox_json.JSONResult;
-import com.openexchange.usm.ox_json.JSONResultType;
-import com.openexchange.usm.ox_json.OXJSONAccess;
-import com.openexchange.usm.ox_json.OXResource;
 import com.openexchange.usm.util.Toolkit;
 
 public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler {
@@ -135,8 +135,8 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     
     private final int _sourceFieldIndex;
 
-    public MailContentTypeTransferHandlerImpl(MailContentType contentType, Log log, OXJSONAccess ajaxAccess) {
-        super(contentType, log, ajaxAccess);
+    public MailContentTypeTransferHandlerImpl(MailContentType contentType, OXJSONAccess ajaxAccess) {
+        super(contentType, ajaxAccess);
         _idIndex = getFieldIndex(MailConstants.FIELD_ID);
         _receivedDateIndex = getFieldIndex(MailConstants.RECEIVED_DATE);
         _sourceFieldIndex = getFieldIndex(MailConstants.SOURCE);
@@ -158,49 +158,49 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     public void sendMail(String mail, Session session) throws USMException {
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(SRC, ONE);
-        JSONResult result = _ajaxAccess.doPut(UtilConstants.MAIL_PATH, UtilConstants.ACTION_NEW, session, parameters, mail);
+        JSONResult result = _ajaxAccess.doPut(CommonConstants.MAIL_PATH, CommonConstants.ACTION_NEW, session, parameters, mail);
         checkResult(result, JSONResultType.JSONObject);
     }
 
     public void sendMail(InputStreamProvider streamProvider, Session session) throws USMException {
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(SRC, ONE);
-        JSONResult result = _ajaxAccess.doPut(UtilConstants.MAIL_PATH, UtilConstants.ACTION_NEW, session, parameters, streamProvider);
+        JSONResult result = _ajaxAccess.doPut(CommonConstants.MAIL_PATH, CommonConstants.ACTION_NEW, session, parameters, streamProvider);
         checkResult(result, JSONResultType.JSONObject);
     }
 
     public Object getMailAttachment(Session session, String folderId, String mailId, String attachmentId) throws USMException {
         Map<String, String> parameters = createMailAttachmentParameters(folderId, mailId, attachmentId);
-        OXResource result = _ajaxAccess.getResource(session, UtilConstants.MAIL_PATH, parameters);
+        OXResource result = _ajaxAccess.getResource(session, CommonConstants.MAIL_PATH, parameters);
         return result;
     }
 
     public ResourceInputStream getMailAttachmentAsStream(Session session, String folderId, String mailId, String attachmentId) throws USMException {
         Map<String, String> parameters = createMailAttachmentParameters(folderId, mailId, attachmentId);
-        ResourceInputStream result = _ajaxAccess.getResourceAsStream(session, UtilConstants.MAIL_PATH, parameters);
+        ResourceInputStream result = _ajaxAccess.getResourceAsStream(session, CommonConstants.MAIL_PATH, parameters);
         return result;
     }
 
     private static Map<String, String> createMailAttachmentParameters(String folderId, String mailId, String attachmentId) {
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.FOLDER, folderId);
-        parameters.put(UtilConstants.ID, mailId);
+        parameters.put(CommonConstants.FOLDER, folderId);
+        parameters.put(CommonConstants.ID, mailId);
         parameters.put(MailConstants.ATTACHMENT, attachmentId);
         parameters.put(SAVE, ONE);
-        parameters.put(UtilConstants.ACTION, MailConstants.ATTACHMENT);
+        parameters.put(CommonConstants.ACTION, MailConstants.ATTACHMENT);
         return parameters;
     }
 
     public String createNewMail(String folderId, int flags, String mailMIMEdataBlock, Session session) throws USMException {
         // TODO: use import instead of new (see svn history!)
         Map<String, String> parameters = buildNewMailParameters(folderId, flags);
-        JSONResult result = _ajaxAccess.doPut(UtilConstants.MAIL_PATH, UtilConstants.ACTION_NEW, session, parameters, mailMIMEdataBlock);
+        JSONResult result = _ajaxAccess.doPut(CommonConstants.MAIL_PATH, CommonConstants.ACTION_NEW, session, parameters, mailMIMEdataBlock);
         return verifyNewMailResult(result);
     }
     
     public String createNewMailFromStream(String folderId, int flags, InputStreamProvider streamProvider, Session session) throws USMException {
         Map<String, String> parameters = buildNewMailParameters(folderId, flags);
-        JSONResult result = _ajaxAccess.doPut(UtilConstants.MAIL_PATH, UtilConstants.ACTION_NEW, session, parameters, streamProvider);
+        JSONResult result = _ajaxAccess.doPut(CommonConstants.MAIL_PATH, CommonConstants.ACTION_NEW, session, parameters, streamProvider);
         return verifyNewMailResult(result);
     }
 
@@ -208,7 +208,7 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         checkResult(result, JSONResultType.JSONObject);
         JSONObject o = result.getJSONObject();
         try {
-            return o.getJSONObject(UtilConstants.RESULT_DATA).getString(UtilConstants.RESULT_ID);
+            return o.getJSONObject(CommonConstants.RESULT_DATA).getString(CommonConstants.RESULT_ID);
         } catch (JSONException e) {
             throw generateException(
                 USMContentTypesUtilErrorCodes.ID_NOT_PRESENT_NUMBER4,
@@ -221,7 +221,7 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     private static Map<String, String> buildNewMailParameters(String folderId, int flag) {
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(SRC, ONE);
-        parameters.put(UtilConstants.FOLDER, folderId);
+        parameters.put(CommonConstants.FOLDER, folderId);
         parameters.put(FLAGS, String.valueOf(flag));
         parameters.put(FORCE, ONE);
         return parameters;
@@ -233,13 +233,13 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         mail.setParentFolderID(folderID);
         mail.commitChanges();
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.ID, messageID);
-        parameters.put(UtilConstants.FOLDER, folderID);
+        parameters.put(CommonConstants.ID, messageID);
+        parameters.put(CommonConstants.FOLDER, folderID);
         parameters.put(UNSEEN, ONE);
         parameters.put(VIEW, view);
         parameters.put(DROP_PREFIX, String.valueOf(dropPrefix));
 
-        JSONResult result = _ajaxAccess.doGet(UtilConstants.MAIL_PATH, action, session, parameters);
+        JSONResult result = _ajaxAccess.doGet(CommonConstants.MAIL_PATH, action, session, parameters);
         if (result.getResultType() == JSONResultType.Error)
             throw new OXCommunicationException(USMContentTypesUtilErrorCodes.OX_RESULT_ERROR_NUMBER2, result.getJSONObject());
         BitSet reqFields = createRequestedFields(_contentType);
@@ -268,18 +268,18 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     }
 
     private void writeDeletedDataObject(DataObject object, boolean hardDelete) throws USMException {
-        if (_journal.isDebugEnabled())
-            _journal.debug(object.getSession() + " Delete mail " + object.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(object.getSession() + " Delete mail " + object.getID());
         checkTypeToWrite(object, DefaultContentTypes.MAIL_ID);
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.TIMESTAMP, String.valueOf(object.getTimestamp()));
+        parameters.put(CommonConstants.TIMESTAMP, String.valueOf(object.getTimestamp()));
         if (hardDelete)
             parameters.put(HARDDELETE, ONE);
         JSONObject jObj = new JSONObject();
         JSONArray array = new JSONArray();
         try {
-            jObj.put(UtilConstants.ID, object.getID());
-            jObj.put(UtilConstants.FOLDER, object.getParentFolderID());
+            jObj.put(CommonConstants.ID, object.getID());
+            jObj.put(CommonConstants.FOLDER, object.getParentFolderID());
 
             array.put(jObj);
         } catch (JSONException e) {
@@ -287,7 +287,7 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
                 USMContentTypesUtilErrorCodes.ERROR_WRITING_DATA_NUMBER2,
                 "Duplicate or null entry in provided key/value pairs");
         }
-        JSONResult result = _ajaxAccess.doPut(UtilConstants.MAIL_PATH, UtilConstants.ACTION_DELETE, object.getSession(), parameters, array);
+        JSONResult result = _ajaxAccess.doPut(CommonConstants.MAIL_PATH, CommonConstants.ACTION_DELETE, object.getSession(), parameters, array);
         checkForNotDeletedObjects(object, result);
     }
 
@@ -300,17 +300,17 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         // parameters.put(UtilConstants.COLUMNS, createColumnsParameter(folder, requestedFields));
         // parameters.put(UtilConstants.TIMESTAMP, String.valueOf(timestamp));
 
-        if (_journal.isDebugEnabled())
-            _journal.debug(folder.getSession() + " Read updates in " + folder.getID());
-        JSONResult result = _ajaxAccess.doGet(UtilConstants.MAIL_PATH, UtilConstants.ACTION_UPDATES, folder.getSession(), parameters);
+        if (LOG.isDebugEnabled())
+            LOG.debug(folder.getSession() + " Read updates in " + folder.getID());
+        JSONResult result = _ajaxAccess.doGet(CommonConstants.MAIL_PATH, CommonConstants.ACTION_UPDATES, folder.getSession(), parameters);
         checkResult(result, JSONResultType.JSONObject);
         return getListOfUpdates(folder, requestedFields, result);
     }
 
     @Override
     public void writeNewDataObject(DataObject object) throws USMException {
-        if (_journal.isErrorEnabled())
-            _journal.error(object.getSession() + " Creating a mail isn't support");
+        if (LOG.isErrorEnabled())
+            LOG.error(object.getSession() + " Creating a mail isn't support");
         throw new UnsupportedContentOperationException(USMContentTypesMailErrorCodes.CREATE_ERROR, "Creating a mail is not supported");
     }
 
@@ -319,10 +319,10 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         checkTypeToWrite(object, DefaultContentTypes.MAIL_ID);
         Map<String, String> parameters = new HashMap<String, String>();
 
-        parameters.put(UtilConstants.ID, object.getID());
-        parameters.put(UtilConstants.FOLDER, object.getOriginalParentFolderID());
+        parameters.put(CommonConstants.ID, object.getID());
+        parameters.put(CommonConstants.FOLDER, object.getOriginalParentFolderID());
         // XXX is it to use? In HTTP Ajax API timestamp isn't use for mail update
-        parameters.put(UtilConstants.TIMESTAMP, String.valueOf(timestamp));
+        parameters.put(CommonConstants.TIMESTAMP, String.valueOf(timestamp));
 
         JSONObject requestBody = new JSONObject();
         if (object.isFieldModified(MailConstants.MAIL_UPDATE_FLAGS)) {
@@ -344,8 +344,8 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         }
         if (requestBody.length() > 0) {
             JSONResult result = _ajaxAccess.doPut(
-                UtilConstants.MAIL_PATH,
-                UtilConstants.ACTION_UPDATE,
+                CommonConstants.MAIL_PATH,
+                CommonConstants.ACTION_UPDATE,
                 object.getSession(),
                 parameters,
                 requestBody);
@@ -354,13 +354,13 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
                 throw new OXCommunicationException(USMContentTypesUtilErrorCodes.OX_RESULT_ERROR_NUMBER4, result.getJSONObject());
             }
         }
-        if (!object.isFieldModified(UtilConstants.PARENTFOLDER_ID))
+        if (!object.isFieldModified(CommonConstants.PARENTFOLDER_ID))
             return;
         requestBody = new JSONObject();
-        putInJSONObject(requestBody, UtilConstants.PARENTFOLDER_ID, object.getParentFolderID());
+        putInJSONObject(requestBody, CommonConstants.PARENTFOLDER_ID, object.getParentFolderID());
         JSONResult result = _ajaxAccess.doPut(
-            UtilConstants.MAIL_PATH,
-            UtilConstants.ACTION_UPDATE,
+            CommonConstants.MAIL_PATH,
+            CommonConstants.ACTION_UPDATE,
             object.getSession(),
             parameters,
             requestBody);
@@ -371,7 +371,7 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
             // if the email is moved to another folder, update the ID of the object with the new id
             JSONObject data = result.getJSONObject().optJSONObject("data");
             if (data != null) {
-                String id = data.optString(UtilConstants.ID, null);
+                String id = data.optString(CommonConstants.ID, null);
                 if (id != null)
                     object.setID(id);
             }
@@ -404,16 +404,16 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     public JSONObject readStructuredMail(DataObject object, int maxAttachmentSize) throws USMException {
         if (object == null || Toolkit.notProvided(object.getID()) || Toolkit.notProvided(object.getParentFolderID()))
             return new JSONObject();
-        if (_journal.isDebugEnabled())
-            _journal.debug(object.getSession() + " Read structured mail with id " + object.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(object.getSession() + " Read structured mail with id " + object.getID());
         checkTypeToWrite(object, _contentType.getID());
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(UNSEEN, ONE);
-        parameters.put(UtilConstants.ID, object.getID());
-        parameters.put(UtilConstants.FOLDER, object.getParentFolderID());
+        parameters.put(CommonConstants.ID, object.getID());
+        parameters.put(CommonConstants.FOLDER, object.getParentFolderID());
         if (maxAttachmentSize >= 0)
             parameters.put(MailConstants.MAX_SIZE, Integer.toString(maxAttachmentSize));
-        JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), UtilConstants.ACTION_GET_STRUCTURE, object.getSession(), parameters);
+        JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), CommonConstants.ACTION_GET_STRUCTURE, object.getSession(), parameters);
         checkResult(result, JSONResultType.JSONObject);
         JSONObject resultObject = null;
         try {
@@ -429,8 +429,8 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     }
 
     public byte[] readMailSource(DataObject object, BitSet requestedFields, boolean ignoreICalAttachments) throws USMException {
-        if (_journal.isDebugEnabled())
-            _journal.debug(object.getSession() + " Read mail with id " + object.getID() + " with ignore ical attachments param: " + ignoreICalAttachments);
+        if (LOG.isDebugEnabled())
+            LOG.debug(object.getSession() + " Read mail with id " + object.getID() + " with ignore ical attachments param: " + ignoreICalAttachments);
         checkTypeToWrite(object, _contentType.getID());
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(UNSEEN, ONE);
@@ -438,15 +438,15 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         parameters.put(SAVE, ONE);
         if (ignoreICalAttachments)
             parameters.put("ignorable", "ics");
-        parameters.put(UtilConstants.ID, object.getID());
-        parameters.put(UtilConstants.FOLDER, object.getParentFolderID());
-        parameters.put(UtilConstants.ACTION, UtilConstants.ACTION_GET);
+        parameters.put(CommonConstants.ID, object.getID());
+        parameters.put(CommonConstants.FOLDER, object.getParentFolderID());
+        parameters.put(CommonConstants.ACTION, CommonConstants.ACTION_GET);
         return _ajaxAccess.getResource(object.getSession(), getOXAjaxAccessPath(), parameters).getData();
     }
 
     @Override
     protected String getOXAjaxAccessPath() {
-        return UtilConstants.MAIL_PATH;
+        return CommonConstants.MAIL_PATH;
     }
 
     @Override
@@ -486,15 +486,15 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
                 JSONObject element = new JSONObject();
                 try {
                     element.put(FOLDER, folder.getID());
-                    element.put(UtilConstants.ID, o.getID());
+                    element.put(CommonConstants.ID, o.getID());
                 } catch (JSONException ignored) {
                     // Ignored because it can not happen
                 }
                 ids.put(element);
             }
             Map<String, String> parameters = new HashMap<String, String>();
-            parameters.put(UtilConstants.COLUMNS, createColumnsParameter(requestedFields));
-            JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_LIST, session, parameters, ids);
+            parameters.put(CommonConstants.COLUMNS, createColumnsParameter(requestedFields));
+            JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), CommonConstants.ACTION_LIST, session, parameters, ids);
             DataObject[] listOfResults = getListOfResults(folder, requestedFields, result);
             return extractDeletedMails(session, listOfResults);
         } catch (OXCommunicationException e) {
@@ -521,8 +521,8 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     }
 
     public JSONObject convertICalToJSON(DataObject mailObject, String attSeqId, String timezone) throws USMException {
-        if (_journal.isDebugEnabled())
-            _journal.debug("Converting iCal attachment to JSONObject for mail: " + mailObject.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug("Converting iCal attachment to JSONObject for mail: " + mailObject.getID());
 
         JSONObject conversionObject = createConversionDataSource(mailObject, attSeqId);
 
@@ -546,8 +546,8 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         }
 
         JSONResult result = _ajaxAccess.doPut(
-            UtilConstants.CONVERSION_PATH,
-            UtilConstants.ACTION_CONVERT,
+            CommonConstants.CONVERSION_PATH,
+            CommonConstants.ACTION_CONVERT,
             mailObject.getSession(),
             new HashMap<String, String>(),
             conversionObject);
@@ -566,16 +566,16 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     }
 
     public JSONObject analyzeICalAttachment(DataObject mailObject, String attSeqId) throws USMException {
-        if (_journal.isDebugEnabled())
-            _journal.debug("Analyzing iCal attachment for mail: " + mailObject.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug("Analyzing iCal attachment for mail: " + mailObject.getID());
 
         JSONObject conversionObject = createITIPDataSource(mailObject, attSeqId);
 
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put("dataSource", COM_OPENEXCHANGE_MAIL_ICAL);
         JSONResult result = _ajaxAccess.doPut(
-            UtilConstants.ITIP_PATH,
-            UtilConstants.ACTION_ANALYZE,
+            CommonConstants.ITIP_PATH,
+            CommonConstants.ACTION_ANALYZE,
             mailObject.getSession(),
             parameters,
             conversionObject);
@@ -594,14 +594,14 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     }
 
     public JSONObject updateObjectBasedOnMeetingRequest(DataObject mailObject, String attSeqId, String action) throws USMException {
-        if (_journal.isDebugEnabled())
-            _journal.debug("Updating object based on iCal attachment for mail: " + mailObject.getID() + ", action: " + action);
+        if (LOG.isDebugEnabled())
+            LOG.debug("Updating object based on iCal attachment for mail: " + mailObject.getID() + ", action: " + action);
 
         JSONObject conversionObject = createITIPDataSource(mailObject, attSeqId);
 
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put("dataSource", COM_OPENEXCHANGE_MAIL_ICAL);
-        JSONResult result = _ajaxAccess.doPut(UtilConstants.ITIP_PATH, action, mailObject.getSession(), parameters, conversionObject);
+        JSONResult result = _ajaxAccess.doPut(CommonConstants.ITIP_PATH, action, mailObject.getSession(), parameters, conversionObject);
         checkResult(result, JSONResultType.JSONObject);
         try {
             JSONArray dataArray = result.getJSONObject().getJSONArray("data");
@@ -616,8 +616,8 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
     }
 
     public JSONObject respondToMeetingRequest(DataObject mailObject, String attSeqId, int confirmation) throws USMException {
-        if (_journal.isDebugEnabled())
-            _journal.debug("Accepting meeting request for mail: " + mailObject.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug("Accepting meeting request for mail: " + mailObject.getID());
 
         JSONObject conversionObject = createITIPDataSource(mailObject, attSeqId);
 
@@ -627,16 +627,16 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         String action = null;
         switch (confirmation) {
         case 1:
-            action = UtilConstants.ACTION_ACCEPT;
+            action = CommonConstants.ACTION_ACCEPT;
             break;
         case 2:
-            action = UtilConstants.ACTION_DECLINE;
+            action = CommonConstants.ACTION_DECLINE;
             break;
         case 3:
-            action = UtilConstants.ACTION_TENTATIVE;
+            action = CommonConstants.ACTION_TENTATIVE;
             break;
         }
-        JSONResult result = _ajaxAccess.doPut(UtilConstants.ITIP_PATH, action, mailObject.getSession(), parameters, conversionObject);
+        JSONResult result = _ajaxAccess.doPut(CommonConstants.ITIP_PATH, action, mailObject.getSession(), parameters, conversionObject);
 
         checkResult(result, JSONResultType.JSONObject);
         JSONObject resultObject = null;
@@ -698,16 +698,16 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
 
     public List<DataObject> searchMails(JSONObject searchCriteria, String folderId, Session session, BitSet requestedFields) throws USMException {
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.COLUMNS, createColumnsParameter(requestedFields));
-        parameters.put(UtilConstants.FOLDER, folderId);
-        JSONResult jResult = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_ALL, session, parameters, searchCriteria);
+        parameters.put(CommonConstants.COLUMNS, createColumnsParameter(requestedFields));
+        parameters.put(CommonConstants.FOLDER, folderId);
+        JSONResult jResult = _ajaxAccess.doPut(getOXAjaxAccessPath(), CommonConstants.ACTION_ALL, session, parameters, searchCriteria);
         return buildSearchResultList(session, requestedFields, jResult);
     }
 
     public List<DataObject> searchMails(String searchText, String folderId, Session session, BitSet requestedFields) throws USMException {
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.COLUMNS, createColumnsParameter(requestedFields));
-        parameters.put(UtilConstants.FOLDER, folderId);
+        parameters.put(CommonConstants.COLUMNS, createColumnsParameter(requestedFields));
+        parameters.put(CommonConstants.FOLDER, folderId);
         JSONObject searchCriteria = new JSONObject();
         JSONArray searchArray = new JSONArray();
         try {
@@ -717,7 +717,7 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         } catch (JSONException ignored) {
             // can not happen
         }
-        JSONResult jResult = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_SEARCH, session, parameters, searchArray);
+        JSONResult jResult = _ajaxAccess.doPut(getOXAjaxAccessPath(), CommonConstants.ACTION_SEARCH, session, parameters, searchArray);
         return buildSearchResultList(session, requestedFields, jResult);
     }
 
@@ -725,9 +725,9 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         JSONArray jsonar;
         try {
             checkResult(jResult, JSONResultType.JSONObject);
-            jsonar = jResult.getJSONObject().getJSONArray(UtilConstants.RESULT_DATA);
+            jsonar = jResult.getJSONObject().getJSONArray(CommonConstants.RESULT_DATA);
         } catch (JSONException e1) {
-            _journal.error(session + " Can not read the result data array for search mails", e1);
+            LOG.error(session + " Can not read the result data array for search mails", e1);
             return Collections.emptyList();
         }
         int length = jsonar.length();
@@ -742,7 +742,7 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
                 updateDataObjectFromJSONArray(newDataObject, requestedFields, columnsArray);
                 resultMails.add(newDataObject);
             } catch (JSONException e) {
-                _journal.error(session + " Can not read the result data for search mails", e);
+                LOG.error(session + " Can not read the result data for search mails", e);
             }
         }
         return resultMails;
@@ -755,15 +755,15 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         Vacation vacation = new Vacation();
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(FLAG, Vacation.RULE_ID);
-        JSONResult jResult = _ajaxAccess.doGet(MAILFILTER_AJAX_PATH, UtilConstants.ACTION_LIST, session, parameters);
+        JSONResult jResult = _ajaxAccess.doGet(MAILFILTER_AJAX_PATH, CommonConstants.ACTION_LIST, session, parameters);
         checkResult(jResult, JSONResultType.JSONObject);
         try {
-            JSONArray jsonar = jResult.getJSONObject().getJSONArray(UtilConstants.RESULT_DATA);
+            JSONArray jsonar = jResult.getJSONObject().getJSONArray(CommonConstants.RESULT_DATA);
             if(jsonar != null && jsonar.length() > 0)  
                 vacation = new Vacation(jsonar.getJSONObject(0));
             return vacation.toJSONObject();
         } catch (JSONException e) {
-            _journal.error(session + " Can not read the vacation rule", e);
+            LOG.error(session + " Can not read the vacation rule", e);
         }
         return null;
     }
@@ -774,7 +774,7 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         // RESULT : {"data":0}
         Map<String, String> parameters = new HashMap<String, String>();
         JSONObject requestBody = createVacationRequestBody(rule);
-        JSONResult jResult = _ajaxAccess.doPut(MAILFILTER_AJAX_PATH, UtilConstants.ACTION_NEW, session, parameters, requestBody);
+        JSONResult jResult = _ajaxAccess.doPut(MAILFILTER_AJAX_PATH, CommonConstants.ACTION_NEW, session, parameters, requestBody);
         checkResult(jResult, JSONResultType.JSONObject);
     }
 
@@ -785,7 +785,7 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         // RESULT: {"data":null}
         Map<String, String> parameters = new HashMap<String, String>();
         JSONObject requestBody = createVacationRequestBody(rule);
-        JSONResult jResult = _ajaxAccess.doPut(MAILFILTER_AJAX_PATH, UtilConstants.ACTION_UPDATE, session, parameters, requestBody);
+        JSONResult jResult = _ajaxAccess.doPut(MAILFILTER_AJAX_PATH, CommonConstants.ACTION_UPDATE, session, parameters, requestBody);
         checkResult(jResult, JSONResultType.JSONObject);
     }
 
@@ -797,7 +797,7 @@ public class MailContentTypeTransferHandlerImpl extends AbstractTransferHandler
         JSONObject requestBody = new JSONObject();
         try {
             requestBody.put(Vacation.ID, (new Vacation(rule).getId()));
-            JSONResult jResult = _ajaxAccess.doPut(MAILFILTER_AJAX_PATH, UtilConstants.ACTION_DELETE, session, parameters, requestBody);
+            JSONResult jResult = _ajaxAccess.doPut(MAILFILTER_AJAX_PATH, CommonConstants.ACTION_DELETE, session, parameters, requestBody);
             checkResult(jResult, JSONResultType.JSONObject);
         } catch (JSONException e) {
             throw generateException(
