@@ -55,32 +55,36 @@ import com.openexchange.usm.api.datatypes.AbstractDataType;
 import com.openexchange.usm.api.session.Session;
 
 public class ConfirmingParticipantDataType extends AbstractDataType<ConfirmingParticipant> {
-	public static final String NAME = "ConfirmingParticipant";
+	
+    public ConfirmingParticipantDataType() {
+	    super("ConfirmingParticipant");
+	}
 
-	public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
+	@Override
+    public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
 		parent.put(((ConfirmingParticipant) value).toJSONObject());
 	}
 
-	public ConfirmingParticipant checkValue(Object o) {
+	@Override
+    public ConfirmingParticipant checkValue(Object o) {
 		if (o != null && !(o instanceof ConfirmingParticipant))
 			generateTypeError(o);
 		return (ConfirmingParticipant) o;
 	}
 
-	public ConfirmingParticipant extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
+	@Override
+    public ConfirmingParticipant extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
 		return array.isNull(index) ? new ConfirmingParticipant() : new ConfirmingParticipant(array.getJSONObject(index));
 	}
 
-	public ConfirmingParticipant extractFromJSONObject(Session session, JSONObject jsonObject, String field)
+	@Override
+    public ConfirmingParticipant extractFromJSONObject(Session session, JSONObject jsonObject, String field)
 			throws JSONException {
 		return jsonObject.isNull(field) ? new ConfirmingParticipant() : new ConfirmingParticipant(jsonObject.getJSONObject(field));
 	}
 
-	public String getName() {
-		return NAME;
-	}
-
-	public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
+	@Override
+    public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
 		parent.put(field, ((ConfirmingParticipant) value).toJSONObject());
 	}
 }
