@@ -55,32 +55,36 @@ import com.openexchange.usm.api.datatypes.AbstractDataType;
 import com.openexchange.usm.api.session.Session;
 
 public class UserParticipantObjectDataType extends AbstractDataType<UserParticipantObject> {
-	public static final String NAME = "UserParticipantObject";
+	
+    public UserParticipantObjectDataType() {
+	    super("UserParticipantObject");
+	}
 
-	public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
+	@Override
+    public void addToJSONArray(Session session, JSONArray parent, Object value) throws JSONException {
 		parent.put(((UserParticipantObject) value).toJSONObject());
 	}
 
-	public UserParticipantObject checkValue(Object o) {
+	@Override
+    public UserParticipantObject checkValue(Object o) {
 		if (o != null && !(o instanceof UserParticipantObject))
 			generateTypeError(o);
 		return (UserParticipantObject) o;
 	}
 
-	public UserParticipantObject extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
+	@Override
+    public UserParticipantObject extractFromJSONArray(Session session, JSONArray array, int index) throws JSONException {
 		return array.isNull(index) ? new UserParticipantObject() : new UserParticipantObject(array.getJSONObject(index));
 	}
 
-	public UserParticipantObject extractFromJSONObject(Session session, JSONObject jsonObject, String field)
+	@Override
+    public UserParticipantObject extractFromJSONObject(Session session, JSONObject jsonObject, String field)
 			throws JSONException {
 		return jsonObject.isNull(field) ? new UserParticipantObject() : new UserParticipantObject(jsonObject.getJSONObject(field));
 	}
 
-	public String getName() {
-		return NAME;
-	}
-
-	public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
+	@Override
+    public void storeInJSONObject(Session session, JSONObject parent, String field, Object value) throws JSONException {
 		parent.put(field, ((UserParticipantObject) value).toJSONObject());
 	}
 }
