@@ -59,22 +59,23 @@ import java.util.List;
 import java.util.Map;
 import java.util.UUID;
 import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-import com.openexchange.usm.api.contenttypes.ResourceInputStream;
+import com.openexchange.usm.api.contenttypes.common.CommonConstants;
+import com.openexchange.usm.api.contenttypes.resource.ResourceInputStream;
 import com.openexchange.usm.api.datatypes.PIMAttachment;
 import com.openexchange.usm.api.datatypes.PIMAttachments;
 import com.openexchange.usm.api.exceptions.OXCommunicationException;
 import com.openexchange.usm.api.exceptions.PIMAttachmentCountLimitExceededException;
 import com.openexchange.usm.api.exceptions.PIMAttachmentSizeLimitExceededException;
 import com.openexchange.usm.api.exceptions.USMException;
+import com.openexchange.usm.api.ox.json.JSONResult;
+import com.openexchange.usm.api.ox.json.JSONResultType;
+import com.openexchange.usm.api.ox.json.OXJSONAccess;
+import com.openexchange.usm.api.ox.json.OXResource;
 import com.openexchange.usm.api.session.DataObject;
-import com.openexchange.usm.contenttypes.util.UtilConstants;
-import com.openexchange.usm.ox_json.JSONResult;
-import com.openexchange.usm.ox_json.JSONResultType;
-import com.openexchange.usm.ox_json.OXJSONAccess;
-import com.openexchange.usm.ox_json.OXResource;
 import com.openexchange.usm.util.TempFile;
 import com.openexchange.usm.util.TempFileStorage;
 import com.openexchange.usm.util.Toolkit;
@@ -115,12 +116,11 @@ public class PIMAttachmentTransferHandler {
 
     private static final String ATTACHMENT_COLUMNS = createColumnsParameter();
 
-    private final Log _journal;
+    private static final Log LOG = LogFactory.getLog(PIMAttachmentTransferHandler.class);
 
     private final OXJSONAccess _ajaxAccess;
 
-    public PIMAttachmentTransferHandler(Log journal, OXJSONAccess ajaxAccess) {
-        _journal = journal;
+    public PIMAttachmentTransferHandler(OXJSONAccess ajaxAccess) {
         _ajaxAccess = ajaxAccess;
     }
 
@@ -135,8 +135,8 @@ public class PIMAttachmentTransferHandler {
     }
 
     private long createNewAttachmentFromData(DataObject object, PIMAttachment attachment) throws USMException {
-        if (_journal.isDebugEnabled())
-            _journal.debug(object.getSession() + " Creating attachment " + attachment + " from data for object" + object.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(object.getSession() + " Creating attachment " + attachment + " from data for object" + object.getID());
         checkAttachmentSizeLimit(object, attachment.getData().length);
         JSONObject requestBody = buildCreateAttachmentJSONRequestBody(object, attachment);
         JSONResult result = _ajaxAccess.storeResource(
@@ -153,8 +153,8 @@ public class PIMAttachmentTransferHandler {
     }
 
     private long createNewAttachmentFromLocalTempfile(DataObject object, PIMAttachment attachment) throws USMException {
-        if (_journal.isDebugEnabled())
-            _journal.debug(object.getSession() + " Creating attachment " + attachment + " from tempfile for object" + object.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(object.getSession() + " Creating attachment " + attachment + " from tempfile for object" + object.getID());
         TempFile tempFile = null;
         try {
             tempFile = TempFileStorage.getTempFileForRead(object.getSession(), attachment.getTempId());
@@ -208,9 +208,9 @@ public class PIMAttachmentTransferHandler {
         JSONObject requestBody;
         try {
             requestBody = new JSONObject(jsonAtt, names);
-            requestBody.put(UtilConstants.ATTACHED, object.getID());
-            requestBody.put(UtilConstants.FOLDER, object.getParentFolderID());
-            requestBody.put(UtilConstants.MODULE, object.getContentType().getCode());
+            requestBody.put(CommonConstants.ATTACHED, object.getID());
+            requestBody.put(CommonConstants.FOLDER, object.getParentFolderID());
+            requestBody.put(CommonConstants.MODULE, object.getContentType().getCode());
         } catch (JSONException e1) {
             throw new USMException(
                 PIMAttachmentErrorCodes.CAN_NOT_CREATE_REQUEST_BODY,
@@ -236,8 +236,8 @@ public class PIMAttachmentTransferHandler {
     public PIMAttachments getAllAttachments(DataObject object) throws USMException {
         if (object.getID() == null) // this means that the object was created by client and still doesn't have ox id
             return UNSET_PIMATTACHMENTS;
-        if (_journal.isDebugEnabled())
-            _journal.debug(object.getSession() + " Read all attachments for object" + object.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(object.getSession() + " Read all attachments for object" + object.getID());
         PIMAttachments completeList = getCompleteAttachmentsList(object, null, null);
         if (completeList == null || completeList.size() == 0)
             return completeList;
@@ -265,15 +265,14 @@ public class PIMAttachmentTransferHandler {
         if (object.getID() == null) // this means that the object was created by client and still doesn't have ox id
             return UNSET_PIMATTACHMENTS;
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.ATTACHED, object.getID());
-        parameters.put(UtilConstants.FOLDER, object.getParentFolderID());
-        parameters.put(UtilConstants.MODULE, String.valueOf(object.getContentType().getCode()));
-        parameters.put(UtilConstants.COLUMNS, ATTACHMENT_COLUMNS);
-        // TODO Enable sorting by parameters after bug 26544 is fixed
-        // parameters.put(UtilConstants.SORT, (sort != null) ? sort : "1");
-        // parameters.put(UtilConstants.ORDER, (order != null) ? order : "asc");
+        parameters.put(CommonConstants.ATTACHED, object.getID());
+        parameters.put(CommonConstants.FOLDER, object.getParentFolderID());
+        parameters.put(CommonConstants.MODULE, String.valueOf(object.getContentType().getCode()));
+        parameters.put(CommonConstants.COLUMNS, ATTACHMENT_COLUMNS);
+        parameters.put(CommonConstants.SORT, (sort != null) ? sort : "1");
+        parameters.put(CommonConstants.ORDER, (order != null) ? order : "asc");
 
-        JSONResult result = _ajaxAccess.doGet(OX_AJAX_PATH, UtilConstants.ACTION_ALL, object.getSession(), parameters);
+        JSONResult result = _ajaxAccess.doGet(OX_AJAX_PATH, CommonConstants.ACTION_ALL, object.getSession(), parameters);
         JSONArray array = extractArrayResult(result);
         int length = array.length();
         if (length == 0)
@@ -284,17 +283,6 @@ public class PIMAttachmentTransferHandler {
                 JSONArray attachmentFields = array.getJSONArray(i);
                 attachments[i] = new PIMAttachment(UUID.randomUUID(), attachmentFields);
             }
-            // TODO Remove explicit sorting by OX ID after bug 26544 is fixed
-            Arrays.sort(attachments, new Comparator<PIMAttachment>() {
-
-                public int compare(PIMAttachment o1, PIMAttachment o2) {
-                    if (o1.getOxId() < o2.getOxId())
-                        return -1;
-                    if (o1.getOxId() > o2.getOxId())
-                        return 1;
-                    return 0;
-                }
-            });
             long timestamp = extractTimestamp(result);
             return new PIMAttachments(timestamp, true, attachments);
         } catch (JSONException e) {
@@ -306,7 +294,7 @@ public class PIMAttachmentTransferHandler {
     }
 
     private static void setSavedUUIDs(DataObject object, PIMAttachment[] pimAtts) {
-        PIMAttachments oldAttachments = (PIMAttachments) object.getFieldContent(UtilConstants.ATTACHMENTS_LAST_MODIFIED);
+        PIMAttachments oldAttachments = (PIMAttachments) object.getFieldContent(CommonConstants.ATTACHMENTS_LAST_MODIFIED);
         if (oldAttachments == null)
             return;
         for (PIMAttachment newAtt : pimAtts) {
@@ -332,7 +320,7 @@ public class PIMAttachmentTransferHandler {
                 "OX server didn't send expected JSONObject",
                 result.toString());
         try {
-            return result.getJSONObject().getJSONArray(UtilConstants.RESULT_DATA);
+            return result.getJSONObject().getJSONArray(CommonConstants.RESULT_DATA);
         } catch (JSONException e) {
             throw new OXCommunicationException(
                 PIMAttachmentErrorCodes.INVALID_OX_RESULT_3,
@@ -355,7 +343,7 @@ public class PIMAttachmentTransferHandler {
                 "OX server didn't send expected JSONObject",
                 result.toString());
         try {
-            return result.getJSONObject().getLong(UtilConstants.TIMESTAMP);
+            return result.getJSONObject().getLong(CommonConstants.TIMESTAMP);
         } catch (JSONException e) {
             throw new OXCommunicationException(
                 PIMAttachmentErrorCodes.INVALID_OX_RESULT_6,
@@ -366,12 +354,12 @@ public class PIMAttachmentTransferHandler {
     }
 
     public long deleteAttachments(DataObject object, PIMAttachment[] attachmentsToDelete) throws USMException {
-        if (_journal.isDebugEnabled())
-            _journal.debug(object.getSession() + " Delete attachments for object" + object.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(object.getSession() + " Delete attachments for object" + object.getID());
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.ATTACHED, object.getID());
-        parameters.put(UtilConstants.FOLDER, object.getParentFolderID());
-        parameters.put(UtilConstants.MODULE, String.valueOf(object.getContentType().getCode()));
+        parameters.put(CommonConstants.ATTACHED, object.getID());
+        parameters.put(CommonConstants.FOLDER, object.getParentFolderID());
+        parameters.put(CommonConstants.MODULE, String.valueOf(object.getContentType().getCode()));
         JSONArray requestBody = new JSONArray();
         for (int i = 0; i < attachmentsToDelete.length; i++) {
             requestBody.put(attachmentsToDelete[i].getOxId());
@@ -392,9 +380,9 @@ public class PIMAttachmentTransferHandler {
     private static long getLastModifiedOfNewestAttachment(DataObject object) throws USMException {
         DataObject objectCopy = object.createCopy(false);
         BitSet fields = new BitSet();
-        fields.set(object.getFieldIndex(UtilConstants.ATTACHMENTS_LAST_MODIFIED));
+        fields.set(object.getFieldIndex(CommonConstants.ATTACHMENTS_LAST_MODIFIED));
         objectCopy.getContentType().getTransferHandler().readDataObject(objectCopy, fields);
-        PIMAttachments attachments = (PIMAttachments) objectCopy.getFieldContent(UtilConstants.ATTACHMENTS_LAST_MODIFIED);
+        PIMAttachments attachments = (PIMAttachments) objectCopy.getFieldContent(CommonConstants.ATTACHMENTS_LAST_MODIFIED);
         long timestamp = (attachments == null) ? 0 : attachments.getTimestamp();
         return timestamp;
     }
@@ -408,19 +396,19 @@ public class PIMAttachmentTransferHandler {
     public ResourceInputStream getAttachmentDataStream(DataObject object, int attachmentId, long offset, long length) throws USMException {
         Map<String, String> parameters = createAttachmentParameters(object, attachmentId);
         if (offset > 0L)
-            parameters.put(UtilConstants.OFF, Long.toString(offset));
+            parameters.put(CommonConstants.OFF, Long.toString(offset));
         if (length >= 0L && length != Long.MAX_VALUE)
-            parameters.put(UtilConstants.LEN, Long.toString(length));
+            parameters.put(CommonConstants.LEN, Long.toString(length));
         return _ajaxAccess.getResourceAsStream(object.getSession(), OX_AJAX_PATH, parameters);
     }
 
     private static Map<String, String> createAttachmentParameters(DataObject object, int attachmentId) {
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.FOLDER, object.getParentFolderID());
-        parameters.put(UtilConstants.ATTACHED, object.getID());
-        parameters.put(UtilConstants.MODULE, String.valueOf(object.getContentType().getCode()));
-        parameters.put(UtilConstants.ID, String.valueOf(attachmentId));
-        parameters.put(UtilConstants.ACTION, ACTION_DOCUMENT);
+        parameters.put(CommonConstants.FOLDER, object.getParentFolderID());
+        parameters.put(CommonConstants.ATTACHED, object.getID());
+        parameters.put(CommonConstants.MODULE, String.valueOf(object.getContentType().getCode()));
+        parameters.put(CommonConstants.ID, String.valueOf(attachmentId));
+        parameters.put(CommonConstants.ACTION, ACTION_DOCUMENT);
         parameters.put(CONTENT_TYPE, APPLICATION_OCTET_STREAM);
         return parameters;
     }
