@@ -56,16 +56,17 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-import com.openexchange.usm.api.contenttypes.ContentType;
-import com.openexchange.usm.api.contenttypes.ContentTypeField;
-import com.openexchange.usm.api.contenttypes.ContentTypeTransferHandler;
-import com.openexchange.usm.api.contenttypes.FolderContentType;
-import com.openexchange.usm.api.contenttypes.OXFolderContent;
-import com.openexchange.usm.api.contenttypes.ResourceInputStream;
-import com.openexchange.usm.api.contenttypes.UnsupportedContentOperationException;
+import com.openexchange.usm.api.contenttypes.common.CommonConstants;
+import com.openexchange.usm.api.contenttypes.common.ContentType;
+import com.openexchange.usm.api.contenttypes.common.ContentTypeField;
+import com.openexchange.usm.api.contenttypes.folder.FolderContentType;
+import com.openexchange.usm.api.contenttypes.folder.OXFolderContent;
+import com.openexchange.usm.api.contenttypes.resource.ResourceInputStream;
+import com.openexchange.usm.api.contenttypes.transferhandlers.ContentTypeTransferHandler;
 import com.openexchange.usm.api.datatypes.DataType;
 import com.openexchange.usm.api.datatypes.PIMAttachment;
 import com.openexchange.usm.api.datatypes.PIMAttachments;
@@ -77,18 +78,19 @@ import com.openexchange.usm.api.exceptions.OXCommunicationException;
 import com.openexchange.usm.api.exceptions.TemporaryDownOrBusyException;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.exceptions.USMIllegalArgumentException;
-import com.openexchange.usm.api.session.ChangeState;
+import com.openexchange.usm.api.exceptions.UnsupportedContentOperationException;
+import com.openexchange.usm.api.ox.json.JSONResult;
+import com.openexchange.usm.api.ox.json.JSONResultType;
+import com.openexchange.usm.api.ox.json.OXJSONAccess;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.api.session.Session;
-import com.openexchange.usm.api.session.SyncResult;
+import com.openexchange.usm.api.session.assets.ChangeState;
+import com.openexchange.usm.api.session.assets.SyncResult;
 import com.openexchange.usm.contenttypes.attachments.PIMAttachmentTransferHandler;
 import com.openexchange.usm.datatypes.tasks.calendar.CommonCalendarTasksFieldNames;
 import com.openexchange.usm.datatypes.tasks.calendar.UserParticipantObject;
-import com.openexchange.usm.ox_json.JSONResult;
-import com.openexchange.usm.ox_json.JSONResultType;
-import com.openexchange.usm.ox_json.OXJSONAccess;
 import com.openexchange.usm.session.dataobject.DataObjectSet;
 
 /**
@@ -98,6 +100,8 @@ import com.openexchange.usm.session.dataobject.DataObjectSet;
  * @author afe
  */
 public abstract class AbstractTransferHandler implements ContentTypeTransferHandler {
+    
+    protected static final Log LOG = LogFactory.getLog(AbstractTransferHandler.class);
 
     protected static final String _LAST_MODIFIED_COLUMN = "5";
 
@@ -119,17 +123,19 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 
     protected final ContentType _contentType;
 
-    protected final Log _journal;
-
     protected final OXJSONAccess _ajaxAccess;
 
     private final PIMAttachmentTransferHandler _pimAttachmentsTransferHandler;
 
-    protected AbstractTransferHandler(ContentType contentType, Log journal, OXJSONAccess ajaxAccess) {
+    /**
+     * Initializes a new {@link AbstractTransferHandler}.
+     * @param contentType
+     * @param ajaxAccess
+     */
+    protected AbstractTransferHandler(ContentType contentType, OXJSONAccess ajaxAccess) {
         _contentType = contentType;
-        _journal = journal;
         _ajaxAccess = ajaxAccess;
-        _pimAttachmentsTransferHandler = new PIMAttachmentTransferHandler(journal, ajaxAccess);
+        _pimAttachmentsTransferHandler = new PIMAttachmentTransferHandler(ajaxAccess);
     }
 
     /**
@@ -175,23 +181,23 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 	public void confirm(DataObject object, int response, String confirmMessage) throws AuthenticationFailedException,
 			OXCommunicationException {
 
-        if (_journal.isDebugEnabled())
-            _journal.debug(object.getSession() + " Confirming appointment or task " + object.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(object.getSession() + " Confirming appointment or task " + object.getID());
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.ID, object.getID());
-        parameters.put(UtilConstants.FOLDER, object.getParentFolderID());
-        parameters.put(UtilConstants.TIMESTAMP, String.valueOf(object.getTimestamp()));
+        parameters.put(CommonConstants.ID, object.getID());
+        parameters.put(CommonConstants.FOLDER, object.getParentFolderID());
+        parameters.put(CommonConstants.TIMESTAMP, String.valueOf(object.getTimestamp()));
 
         JSONObject requestBody = new JSONObject();
         try {
             requestBody.put("confirmation", response);
             requestBody.put("confirmmessage", confirmMessage);
-            requestBody.put(UtilConstants.ID, computeFolderOwnerID(object));
+            requestBody.put(CommonConstants.ID, computeFolderOwnerID(object));
         } catch (JSONException e) {
 			throw generateException(USMContentTypesUtilErrorCodes.CONFIRM_ERROR_NUMBER1, object,
 					"can not create request body for confirming appoinment or task", e);
         }
-		JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_CONFIRM, object.getSession(),
+		JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), CommonConstants.ACTION_CONFIRM, object.getSession(),
 				parameters, requestBody);
 
         if (result.getResultType() == JSONResultType.Error) {
@@ -207,13 +213,13 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 
 	public void confirm(DataObject object, int response, String confirmMessage, String participantId)
 			throws AuthenticationFailedException, OXCommunicationException {
-        if (_journal.isDebugEnabled())
-			_journal.debug(object.getSession() + " Confirming appointment " + object.getID() + " for participant: "
+        if (LOG.isDebugEnabled())
+			LOG.debug(object.getSession() + " Confirming appointment " + object.getID() + " for participant: "
 					+ participantId);
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.ID, object.getID());
-        parameters.put(UtilConstants.FOLDER, object.getParentFolderID());
-        parameters.put(UtilConstants.TIMESTAMP, String.valueOf(object.getTimestamp()));
+        parameters.put(CommonConstants.ID, object.getID());
+        parameters.put(CommonConstants.FOLDER, object.getParentFolderID());
+        parameters.put(CommonConstants.TIMESTAMP, String.valueOf(object.getTimestamp()));
 
         JSONObject requestBody = new JSONObject();
         try {
@@ -225,7 +231,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 			throw generateException(USMContentTypesUtilErrorCodes.CONFIRM_ERROR_NUMBER4, object,
 					"can not create request body for confirming appoinment for participant", e);
         }
-		JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_CONFIRM, object.getSession(),
+		JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), CommonConstants.ACTION_CONFIRM, object.getSession(),
 				parameters, requestBody);
 
         if (result.getResultType() == JSONResultType.Error) {
@@ -261,7 +267,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 
         JSONObject obj;
         try {
-            obj = jObject.getJSONObject(UtilConstants.RESULT_DATA);
+            obj = jObject.getJSONObject(CommonConstants.RESULT_DATA);
         } catch (JSONException e1) {
 			throw generateException(USMContentTypesUtilErrorCodes.DATA_NOT_PRESENT_NUMBER5, destination,
 					"update object: data not present", e1);
@@ -275,9 +281,9 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
     }
 
     protected void readOptionalTimestamp(JSONObject object, DataObject destination) throws OXCommunicationException {
-        if (object.has(UtilConstants.RESULT_TIMESTAMP)) {
+        if (object.has(CommonConstants.RESULT_TIMESTAMP)) {
             try {
-                long timestamp = object.getLong(UtilConstants.RESULT_TIMESTAMP);
+                long timestamp = object.getLong(CommonConstants.RESULT_TIMESTAMP);
                 destination.setTimestamp(timestamp);
             } catch (JSONException e1) {
 				throw generateException(USMContentTypesUtilErrorCodes.INVALID_TIMESTAMP_NUMBER1, destination,
@@ -397,12 +403,12 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         if (notDeletedArray != null && notDeletedArray.length() > 0) {
             int len = notDeletedArray.length();
             for (int i = 0; i < len; i++) {
-                if (_journal.isDebugEnabled()) {
+                if (LOG.isDebugEnabled()) {
                     try {
-						_journal.debug(object.getSession() + " " + notDeletedArray.getString(i)
+						LOG.debug(object.getSession() + " " + notDeletedArray.getString(i)
 								+ " not deleted, modified after " + object.getTimestamp());
                     } catch (JSONException e) {
-						_journal.error(object.getSession() + " Can't read ID of not deleted object " + object.getID()
+						LOG.error(object.getSession() + " Can't read ID of not deleted object " + object.getID()
 								+ " from JSONResult", e);
                     }
                 }
@@ -444,7 +450,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         checkResult(result, JSONResultType.JSONObject);
         JSONObject jsonObject = result.getJSONObject();
         try {
-            jsonar = jsonObject.getJSONArray(UtilConstants.RESULT_DATA);
+            jsonar = jsonObject.getJSONArray(CommonConstants.RESULT_DATA);
         } catch (JSONException e) {
 			throw generateException(USMContentTypesUtilErrorCodes.DATA_NOT_PRESENT_NUMBER4, folder,
 					"getListOfResults: data array not present", e);
@@ -453,8 +459,8 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         if (length == 0)
             return SyncResult.EMPTY_DATA_OBJECT_ARRAY;
         try {
-            if (jsonObject.has(UtilConstants.RESULT_TIMESTAMP))
-                timestamp = jsonObject.getLong(UtilConstants.RESULT_TIMESTAMP);
+            if (jsonObject.has(CommonConstants.RESULT_TIMESTAMP))
+                timestamp = jsonObject.getLong(CommonConstants.RESULT_TIMESTAMP);
         } catch (JSONException e) {
 			throw generateException(USMContentTypesUtilErrorCodes.INVALID_TIMESTAMP_NUMBER2, folder,
 					"getListOfResults: invalid timestamp", e);
@@ -490,10 +496,10 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         JSONArray jsonar = extractArrayResult(result);
         long timestamp;
         try {
-            timestamp = result.getJSONObject().getLong(UtilConstants.RESULT_TIMESTAMP);
+            timestamp = result.getJSONObject().getLong(CommonConstants.RESULT_TIMESTAMP);
         } catch (JSONException e) {
-            if (_journal.isDebugEnabled())
-                _journal.debug(folder.getSession() + " Folder updates: could not read timestamp from result");
+            if (LOG.isDebugEnabled())
+                LOG.debug(folder.getSession() + " Folder updates: could not read timestamp from result");
             timestamp = 0;
         }
         List<DataObject> dataObjects = new ArrayList<DataObject>();
@@ -541,9 +547,9 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
     protected JSONArray extractArrayResult(JSONResult result) throws OXCommunicationException, InternalUSMException {
         checkResult(result, JSONResultType.JSONObject);
         try {
-            return result.getJSONObject().getJSONArray(UtilConstants.RESULT_DATA);
+            return result.getJSONObject().getJSONArray(CommonConstants.RESULT_DATA);
         } catch (JSONException e) {
-            _journal.error("OX server did not send data array: " + result.toString());
+            LOG.error("OX server did not send data array: " + result.toString());
 			throw new OXCommunicationException(USMContentTypesUtilErrorCodes.DATA_NOT_PRESENT_NUMBER3,
 					"OX server did not send data array", e, result.toString());
         }
@@ -578,20 +584,20 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         if (result.getResultType() == JSONResultType.JSONObject && result.getJSONObject().has("code")) {
             try {
                 JSONObject errorObject = result.getJSONObject();
-                int category = errorObject.optInt(UtilConstants.CATEGORY);
-                String message = errorObject.getString(UtilConstants.ERROR);
-                String code = errorObject.getString(UtilConstants.CODE);
+                int category = errorObject.optInt(CommonConstants.CATEGORY);
+                String message = errorObject.getString(CommonConstants.ERROR);
+                String code = errorObject.getString(CommonConstants.CODE);
                 JSONArray errorParams = errorObject.getJSONArray(ERROR_PARAMS);
                 JSONObject errorDetails = new JSONObject();
-                errorDetails.put(UtilConstants.CATEGORY, category);
-                errorDetails.put(UtilConstants.ERROR, message);
-                errorDetails.put(UtilConstants.CODE, code);
+                errorDetails.put(CommonConstants.CATEGORY, category);
+                errorDetails.put(CommonConstants.ERROR, message);
+                errorDetails.put(CommonConstants.CODE, code);
                 errorDetails.put(ERROR_PARAMS, errorParams);
                 if (OXErrorConstants.MSG_1016.equals(code) || OXErrorConstants.IMAP_1016.equals(code))
 					throw new TemporaryDownOrBusyException(USMContentTypesUtilErrorCodes.IMAP_DOWN, message,
 							errorDetails);
-            } catch (JSONException e) {
-
+            } catch (JSONException ignored) {
+                  //should not happen - thrown on object creation
             }
         }
     }
@@ -599,9 +605,9 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 	protected void checkConflictingChange(JSONObject errorObject) throws ConflictingChangeException,
 			InternalUSMException {
         try {
-            int category = errorObject.optInt(UtilConstants.CATEGORY);
-            String message = errorObject.getString(UtilConstants.ERROR);
-            String code = errorObject.getString(UtilConstants.CODE);
+            int category = errorObject.optInt(CommonConstants.CATEGORY);
+            String message = errorObject.getString(CommonConstants.ERROR);
+            String code = errorObject.getString(CommonConstants.CODE);
 			if (category == OXErrorConstants.CATEGORY_CONFLICTING_CHANGE
 					|| (category == OXErrorConstants.CATEGORY_PERMISSION && OXErrorConstants.CON_0119.equals(code))
 					|| (category == OXErrorConstants.CATEGORY_TRY_AGAIN && OXErrorConstants.CON_0240.equals(code))) {
@@ -614,24 +620,26 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         }
     }
 
+    @Override
     public void readDataObject(DataObject object, BitSet requestedFields) throws USMException {
         readDataObject(object, requestedFields, new HashMap<String, String>());
     }
 
 	protected void readDataObject(DataObject object, BitSet requestedFields, Map<String, String> parameters)
 			throws USMException {
-        if (_journal.isDebugEnabled())
-            _journal.debug(object.getSession() + " Read " + _contentType.getID() + " with id " + object.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(object.getSession() + " Read " + _contentType.getID() + " with id " + object.getID());
         checkTypeToWrite(object, _contentType.getID());
-        parameters.put(UtilConstants.ID, object.getID());
+        parameters.put(CommonConstants.ID, object.getID());
         if (_contentType.canBeFolderElementsContentType())
-            parameters.put(UtilConstants.FOLDER, object.getParentFolderID());
-		JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), UtilConstants.ACTION_GET, object.getSession(),
+            parameters.put(CommonConstants.FOLDER, object.getParentFolderID());
+		JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), CommonConstants.ACTION_GET, object.getSession(),
 				parameters);
         checkResult(result, JSONResultType.JSONObject);
         updateDataObjectFromJSONResult(object, requestedFields, result);
     }
 
+    @Override
     public DataObject[] readFolderContent(Folder folder) throws USMException {
         return readFolderContent(folder, Integer.MAX_VALUE, null).getObjects();
     }
@@ -640,18 +648,19 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         return readOptimizedFolderContent(folder, limit, filter);
     }
 
+    @Override
     public DataObject[] readFolderContent(Folder folder, BitSet requestedFields) throws USMException {
         return readCompleteFolderContent(folder, requestedFields);
     }
 
     protected DataObject[] readCompleteFolderContent(Folder folder, BitSet requestedFields) throws USMException {
-        if (_journal.isDebugEnabled())
-            _journal.debug(folder.getSession() + " Read all " + _contentType.getID() + " in folder " + folder.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(folder.getSession() + " Read all " + _contentType.getID() + " in folder " + folder.getID());
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.FOLDER, folder.getID());
-        parameters.put(UtilConstants.COLUMNS, createColumnsParameter(requestedFields));
+        parameters.put(CommonConstants.FOLDER, folder.getID());
+        parameters.put(CommonConstants.COLUMNS, createColumnsParameter(requestedFields));
         addObjectsLimitParameters(folder.getSession(), parameters);
-        return performActionAndCheckRights(UtilConstants.ACTION_ALL, folder, requestedFields, parameters);
+        return performActionAndCheckRights(CommonConstants.ACTION_ALL, folder, requestedFields, parameters);
     }
 
 	protected DataObject[] performActionAndCheckRights(String action, Folder folder, BitSet requestedFields,
@@ -679,23 +688,24 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
         return (own_rights & 0x3F80) != 0;
     }
 
+    @Override
     public void writeDeletedDataObject(DataObject object) throws USMException {
-        writeExtendedDeleteDataObject(object, UtilConstants.FOLDER, object.getParentFolderID());
+        writeExtendedDeleteDataObject(object, CommonConstants.FOLDER, object.getParentFolderID());
     }
 
     protected void writeExtendedDeleteDataObject(DataObject object, String... extraKeyValuePairs) throws USMException {
         if ((extraKeyValuePairs.length & 1) != 0)
 			throw new USMIllegalArgumentException(USMContentTypesUtilErrorCodes.ERROR_WRITING_DATA_NUMBER4,
                 "Extra key identifier without following field name");
-        if (_journal.isDebugEnabled())
-			_journal.debug(object.getSession() + " Delete " + _contentType.getID() + " with id " + object.getID()
+        if (LOG.isDebugEnabled())
+			LOG.debug(object.getSession() + " Delete " + _contentType.getID() + " with id " + object.getID()
 					+ Arrays.toString(extraKeyValuePairs));
         checkTypeToWrite(object, _contentType.getID());
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.TIMESTAMP, String.valueOf(object.getTimestamp()));
+        parameters.put(CommonConstants.TIMESTAMP, String.valueOf(object.getTimestamp()));
         JSONObject jObj = new JSONObject();
         try {
-            jObj.put(UtilConstants.ID, object.getID());
+            jObj.put(CommonConstants.ID, object.getID());
             for (int i = 0; i < extraKeyValuePairs.length; i += 2) {
                 jObj.put(extraKeyValuePairs[i], extraKeyValuePairs[i + 1]);
             }
@@ -703,31 +713,33 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 			throw new USMIllegalArgumentException(USMContentTypesUtilErrorCodes.ERROR_WRITING_DATA_NUMBER5,
                 "Duplicate or null entry in provided key/value pairs");
         }
-		JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_DELETE, object.getSession(),
+		JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), CommonConstants.ACTION_DELETE, object.getSession(),
 				parameters, jObj);
         checkForNotDeletedObjects(object, result);
         readOptionalTimestamp(result.getJSONObject(), object);
     }
 
+    @Override
     public void writeNewDataObject(DataObject object) throws USMException {
-        if (_journal.isDebugEnabled())
-            _journal.debug(object.getSession() + " New " + _contentType.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(object.getSession() + " New " + _contentType.getID());
         checkTypeToWrite(object, _contentType.getID());
         Map<String, String> parameters = new HashMap<String, String>();
         JSONObject requestBody = createRequestBody(object, false, true);
-		JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_NEW, object.getSession(),
+		JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), CommonConstants.ACTION_NEW, object.getSession(),
 				parameters, requestBody);
         checkResult(result, JSONResultType.JSONObject);
         JSONObject o = result.getJSONObject();
         readOptionalTimestamp(o, object);
         try {
-            object.setID(o.getJSONObject(UtilConstants.RESULT_DATA).getString(UtilConstants.RESULT_ID));
+            object.setID(o.getJSONObject(CommonConstants.RESULT_DATA).getString(CommonConstants.RESULT_ID));
         } catch (JSONException e) {
 			throw generateException(USMContentTypesUtilErrorCodes.ID_NOT_PRESENT_NUMBER4, object,
 					"Missing result ID on new " + _contentType.getID(), e);
         }
     }
 
+    @Override
     public void writeUpdatedDataObject(DataObject object, long timestamp) throws USMException {
         writeStandardUpdateDataObject(object, timestamp, false);
     }
@@ -735,21 +747,21 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 	protected void writeStandardUpdateDataObject(DataObject object, long timestamp, boolean isFolder)
 			throws InternalUSMException, AuthenticationFailedException, OXCommunicationException,
 			FolderNotFoundException {
-        if (_journal.isDebugEnabled())
-            _journal.debug(object.getSession() + " Updating " + _contentType.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(object.getSession() + " Updating " + _contentType.getID());
         checkTypeToWrite(object, _contentType.getID());
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.ID, object.getID());
+        parameters.put(CommonConstants.ID, object.getID());
         String folderTree = object.getSession().getPersistentField(FolderContentType.FOLDER_TREE);
         if (!isFolder) {
-            parameters.put(UtilConstants.FOLDER, object.getOriginalParentFolderID());
+            parameters.put(CommonConstants.FOLDER, object.getOriginalParentFolderID());
         } else if (folderTree != null  && folderTree.length() > 0) {
-            parameters.put(UtilConstants.TREE, folderTree);
+            parameters.put(CommonConstants.TREE, folderTree);
         }
-        parameters.put(UtilConstants.TIMESTAMP, String.valueOf(timestamp));
+        parameters.put(CommonConstants.TIMESTAMP, String.valueOf(timestamp));
         JSONObject requestBody = createRequestBody(object, true, false);
         // printTimeValues("Change", requestBody);
-		JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_UPDATE, object.getSession(),
+		JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), CommonConstants.ACTION_UPDATE, object.getSession(),
 				parameters, requestBody);
         if (isFolder) {
             if (result.getResultType() == JSONResultType.Error) {
@@ -759,9 +771,9 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
             }
             checkResult(result, JSONResultType.JSONObject);
             JSONObject o = result.getJSONObject();
-            if (o.has(UtilConstants.RESULT_DATA)) {
+            if (o.has(CommonConstants.RESULT_DATA)) {
                 try {
-                    object.setID(o.getString(UtilConstants.RESULT_DATA));
+                    object.setID(o.getString(CommonConstants.RESULT_DATA));
                 } catch (JSONException e) {
 					throw generateException(USMContentTypesUtilErrorCodes.DATA_INVALID, object,
 							"update object: invalid folder id", e);
@@ -777,8 +789,8 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 
     private boolean isFolderNotExistError(JSONObject errorObject) throws InternalUSMException {
         try {
-            int category = errorObject.optInt(UtilConstants.CATEGORY);
-            String code = errorObject.getString(UtilConstants.CODE);
+            int category = errorObject.optInt(CommonConstants.CATEGORY);
+            String code = errorObject.getString(CommonConstants.CODE);
             if (category == OXErrorConstants.CATEGORY_CODE_ERROR && OXErrorConstants.IMAP_1002.equals(code)) {
                 return true;
             }
@@ -804,10 +816,11 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
     // }
     // }
 
-	public DataObject[] readUpdatedFolderContent(Folder folder, BitSet requestedFields, long timestamp)
+	@Override
+    public DataObject[] readUpdatedFolderContent(Folder folder, BitSet requestedFields, long timestamp)
 			throws USMException {
-		return readStandardUpdatedFolderContent(folder, timestamp, requestedFields, UtilConstants.ACTION_UPDATES,
-				UtilConstants.FOLDER);
+		return readStandardUpdatedFolderContent(folder, timestamp, requestedFields, CommonConstants.ACTION_UPDATES,
+				CommonConstants.FOLDER);
     }
 
 	protected DataObject[] readStandardUpdatedFolderContent(Folder folder, long timestamp, BitSet requestedFields,
@@ -825,25 +838,25 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 	protected DataObject[] readStandardUpdatedFolderContent(Folder folder, long timestamp, BitSet requestedFields,
 			String action, String folderKey, String sort, String order, String start, String end, String folderTree)
 			throws USMException {
-        if (_journal.isDebugEnabled())
-			_journal.debug(folder.getSession() + " Read updated " + _contentType.getID() + " after " + timestamp
+        if (LOG.isDebugEnabled())
+			LOG.debug(folder.getSession() + " Read updated " + _contentType.getID() + " after " + timestamp
 					+ " in folder " + folder.getID());
         Map<String, String> parameters = new HashMap<String, String>();
         parameters.put(folderKey, folder.getID()); // object ID of the folder
-        parameters.put(UtilConstants.COLUMNS, createColumnsParameter(requestedFields));
-        parameters.put(UtilConstants.TIMESTAMP, String.valueOf(timestamp));
+        parameters.put(CommonConstants.COLUMNS, createColumnsParameter(requestedFields));
+        parameters.put(CommonConstants.TIMESTAMP, String.valueOf(timestamp));
         if (sort != null) {
-            parameters.put(UtilConstants.SORT, sort);
+            parameters.put(CommonConstants.SORT, sort);
             if (order != null)
-                parameters.put(UtilConstants.ORDER, order);
+                parameters.put(CommonConstants.ORDER, order);
         }
         if (start != null) {
-            parameters.put(UtilConstants.START, start);
+            parameters.put(CommonConstants.START, start);
             if (end != null)
-                parameters.put(UtilConstants.END, end);
+                parameters.put(CommonConstants.END, end);
         }
         if (folderTree != null) {
-            parameters.put(UtilConstants.TREE, folderTree);
+            parameters.put(CommonConstants.TREE, folderTree);
         }
         addObjectsLimitParameters(folder.getSession(), parameters);
         addShowPrivateParameter(parameters, folder.getSession());
@@ -921,30 +934,35 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 
     protected abstract String getOXAjaxAccessPath();
 
+    @Override
     public long createNewAttachment(DataObject object, PIMAttachment attachment) throws USMException {
         if (!_contentType.supportsPIMAttachments())
             return 0L;
         return _pimAttachmentsTransferHandler.createNewAttachment(object, attachment);
     }
 
+    @Override
     public PIMAttachments getAllAttachments(DataObject object) throws USMException {
         if (!_contentType.supportsPIMAttachments())
             return null;
         return _pimAttachmentsTransferHandler.getAllAttachments(object);
     }
 
+    @Override
     public long deleteAttachments(DataObject object, PIMAttachment... attachmentsToDelete) throws USMException {
         if (!_contentType.supportsPIMAttachments())
             return 0L;
         return _pimAttachmentsTransferHandler.deleteAttachments(object, attachmentsToDelete);
     }
 
+    @Override
     public byte[] getAttachmentData(DataObject object, int attachmentId) throws USMException {
         if (!_contentType.supportsPIMAttachments())
             return null;
         return _pimAttachmentsTransferHandler.getAttachmentData(object, attachmentId);
     }
 
+    @Override
     public ResourceInputStream getAttachmentDataStream(DataObject object, int attachmentId, long offset, long length) throws USMException {
         if (!_contentType.supportsPIMAttachments())
             return null;
@@ -960,15 +978,15 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
     protected void addObjectsLimitParameters(int limit, String defaultSortColumn, Map<String, String> parameters) {
         parameters.put(LEFT_HAND_LIMIT, "0");
         parameters.put(RIGHT_HAND_LIMIT, String.valueOf(limit));
-        if (!parameters.containsKey(UtilConstants.SORT)) {
-            parameters.put(UtilConstants.SORT, defaultSortColumn);
-            parameters.put(UtilConstants.ORDER, "desc");
+        if (!parameters.containsKey(CommonConstants.SORT)) {
+            parameters.put(CommonConstants.SORT, defaultSortColumn);
+            parameters.put(CommonConstants.ORDER, "desc");
         }
     }
 
     protected OXFolderContent readOptimizedFolderContent(Folder folder, int limit, DataObjectFilter filter) throws USMException {
-        if (_journal.isDebugEnabled())
-            _journal.debug(folder.getSession() + " Read all " + _contentType.getID() + " in folder " + folder.getID());
+        if (LOG.isDebugEnabled())
+            LOG.debug(folder.getSession() + " Read all " + _contentType.getID() + " in folder " + folder.getID());
         if (CHECK_ACCESS_RIGHTS_BEFORE_FOLDER_READ && !hasFolderReadRights(folder))
             return _EMPTY_FOLDER_CONTENT;
         try {
@@ -987,7 +1005,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
                 if (cachedObject == null) {
                     newObjects.add(id);
                 } else {
-                    Object o = cachedObject.getFieldContent(UtilConstants.LAST_MODIFIED);
+                    Object o = cachedObject.getFieldContent(CommonConstants.LAST_MODIFIED);
                     if (!(o instanceof Number) || ((Number) o).longValue() != currentTimestamps.getLastModified(i)) {
                         changedObjects.add(id);
                     }
@@ -1013,15 +1031,15 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 
     protected OXObjectIDList getCurrentTimestampsFromOX(Folder folder) throws AuthenticationFailedException, OXCommunicationException, InternalUSMException {
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.FOLDER, folder.getID());
-        parameters.put(UtilConstants.COLUMNS, _COLUMNS_ID_AND_LAST_MODIFIED);
+        parameters.put(CommonConstants.FOLDER, folder.getID());
+        parameters.put(CommonConstants.COLUMNS, _COLUMNS_ID_AND_LAST_MODIFIED);
         addExtraTimestampListParameters(parameters, folder.getSession());
         Session session = folder.getSession();
-        parameters.put(UtilConstants.START, String.valueOf(session.getStartDate()));
-        parameters.put(UtilConstants.END, String.valueOf(session.getEndDate()));
+        parameters.put(CommonConstants.START, String.valueOf(session.getStartDate()));
+        parameters.put(CommonConstants.END, String.valueOf(session.getEndDate()));
         addObjectsLimitParameters(folder.getSession(), parameters);
         long defaultTimestamp = System.currentTimeMillis();
-        JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), UtilConstants.ACTION_ALL, folder.getSession(), parameters);
+        JSONResult result = _ajaxAccess.doGet(getOXAjaxAccessPath(), CommonConstants.ACTION_ALL, folder.getSession(), parameters);
         checkResult(result, JSONResultType.JSONObject);
         JSONObject jsonObject = result.getJSONObject();
         try {
@@ -1064,20 +1082,20 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 
     protected DataObject[] readSomeObjectsFromOX(Folder folder, List<String> objectsToRead, BitSet requestedFields) throws UnsupportedContentOperationException, AuthenticationFailedException, OXCommunicationException, InternalUSMException {
         Map<String, String> parameters = new HashMap<String, String>();
-        parameters.put(UtilConstants.COLUMNS, createColumnsParameter(requestedFields));
+        parameters.put(CommonConstants.COLUMNS, createColumnsParameter(requestedFields));
         JSONArray ids = new JSONArray();
         for (String id : objectsToRead) {
             JSONObject element = new JSONObject();
             try {
-                element.put(UtilConstants.FOLDER, folder.getID());
-                element.put(UtilConstants.ID, id);
+                element.put(CommonConstants.FOLDER, folder.getID());
+                element.put(CommonConstants.ID, id);
             } catch (JSONException ignored) {
                 // Ignored because it can not happen
             }
             ids.put(element);
         }
         addShowPrivateParameter(parameters, folder.getSession());
-        JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), UtilConstants.ACTION_LIST, folder.getSession(), parameters, ids);
+        JSONResult result = _ajaxAccess.doPut(getOXAjaxAccessPath(), CommonConstants.ACTION_LIST, folder.getSession(), parameters, ids);
         return getListOfResults(folder, requestedFields, result);
     }
 
@@ -1101,5 +1119,6 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
     }
 
     protected void finishDataObjectFromOptimizedRead(DataObject o) {
+        //empty
     }
 }
