@@ -55,12 +55,16 @@ import java.sql.SQLException;
 import java.sql.Statement;
 import java.util.HashSet;
 import java.util.Set;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.update.Schema;
 import com.openexchange.groupware.update.UpdateTask;
 import com.openexchange.usm.util.Toolkit;
 
 public abstract class USMBaseUpdateTask implements UpdateTask {
+    
+    private static final Log LOG = LogFactory.getLog(USMBaseUpdateTask.class);
 	/**
 	 * The object type "TABLE"
 	 */
@@ -106,19 +110,20 @@ public abstract class USMBaseUpdateTask implements UpdateTask {
 		_provider = updateTaskProvider;
 	}
 
-	public int getPriority() {
+	@Override
+    public int getPriority() {
 		return UpdateTaskPriority.LOW.priority;
 	}
 
-	public void perform(Schema schema, int contextId) throws OXException {
+	@Override
+    public void perform(Schema schema, int contextId) throws OXException {
 		String taskName = getClass().getName();
 		int i = taskName.lastIndexOf('.');
 		if (i >= 0)
 			taskName = taskName.substring(i + 1);
-		_provider.getJournal().debug("Performing UpdateTask '" + taskName + "'(" + addedWithVersion() + ")");
+		LOG.debug("Performing UpdateTask '" + taskName + "'(" + addedWithVersion() + ")");
 		doPerform(schema, contextId);
-		_provider.getJournal()
-				.info("UpdateTask '" + taskName + "'(" + addedWithVersion() + ") successfully performed!");
+		LOG.info("UpdateTask '" + taskName + "'(" + addedWithVersion() + ") successfully performed!");
 	}
 
 	protected abstract void doPerform(Schema schema, int contextId) throws OXException;
