@@ -53,8 +53,8 @@ import java.sql.SQLException;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.update.PerformParameters;
 import com.openexchange.groupware.update.Schema;
-import com.openexchange.usm.api.database.DatabaseAccessException;
-import com.openexchange.usm.api.exceptions.USMSQLException;
+import com.openexchange.usm.api.database.StorageAccessException;
+import com.openexchange.usm.api.exceptions.USMStorageException;
 
 public class USMTablesUpdateTask extends USMBaseUpdateTask {
 
@@ -62,7 +62,8 @@ public class USMTablesUpdateTask extends USMBaseUpdateTask {
 		super(updateTaskProvider);
 	}
 
-	public int addedWithVersion() {
+	@Override
+    public int addedWithVersion() {
 		return 37;
 	}
 
@@ -80,13 +81,13 @@ public class USMTablesUpdateTask extends USMBaseUpdateTask {
 			try {
 				con = _provider.getDatabaseService().getForUpdateTask(contextId);
 				String tablename = TableDefinition.SEQUENCE_TABLES_NAMES[i];
-				TableDefinition.generateSequence(tablename, con, _provider.getJournal(), true, !tableExists(tablename,
+				TableDefinition.generateSequence(tablename, con, true, !tableExists(tablename,
 						con.getMetaData()));
 			} catch (SQLException e) {
 				throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
-			} catch (USMSQLException e) {
+			} catch (USMStorageException e) {
 				throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
-			} catch (DatabaseAccessException e) {
+			} catch (StorageAccessException e) {
 				throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
 			} finally {
 				if (con != null)
