@@ -46,69 +46,52 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.usm.database.ox;
 
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.List;
-import org.apache.commons.logging.Log;
-import org.osgi.service.component.ComponentContext;
 import com.openexchange.database.DatabaseService;
 import com.openexchange.groupware.update.UpdateTask;
 import com.openexchange.groupware.update.UpdateTaskProviderService;
-import com.openexchange.usm.api.database.DatabaseAccess;
 import com.openexchange.usm.database.ox.update.ChangeCollationUpdateTask;
 import com.openexchange.usm.database.ox.update.USMCreatePrimaryKeyUpdateTask;
 import com.openexchange.usm.database.ox.update.USMTablesUpdateTaskV2;
 import com.openexchange.usm.database.ox.update.USMUUIDTablesUpdateTaskV2;
-import com.openexchange.usm.journal.Journal;
 
 public class USMUpdateTaskProvider implements UpdateTaskProviderService {
 
-	private DatabaseService _service;
-	private Log _journal;
+    private DatabaseService _service;
 
-	/*
-	 * (non-Javadoc)
-	 * @see org.osgi.framework.BundleActivator#start(org.osgi.framework.BundleContext)
-	 */
-	public void activate(ComponentContext context) {
-		Journal journal = (Journal) context.locateService(Journal.class.getName());
-		_journal = journal.getLog(DatabaseAccess.class);
-		_service = (DatabaseService) context.locateService(DatabaseService.class.getName());
-		_journal.info("UpdateTaskProviderService 'USMUpdateTaskProvider' activated");
-	}
+    /**
+     * Initializes a new {@link USMUpdateTaskProvider}.
+     * 
+     * @param dbService
+     */
+    public USMUpdateTaskProvider(DatabaseService dbService) {
+        _service = dbService;
+    }
 
-	/*
-	 * (non-Javadoc)
-	 * @see org.osgi.framework.BundleActivator#stop(org.osgi.framework.BundleContext)
-	 */
-	public void deactivate(ComponentContext context) {
-		_service = null;
-		_journal.info("UpdateTaskProviderService 'USMUpdateTaskProvider' deactivated");
-		_journal = null;
-	}
+    @Override
+    public Collection<UpdateTask> getUpdateTasks() {
+        List<UpdateTask> updateTasks = new ArrayList<UpdateTask>();
+        updateTasks.add(new USMTablesUpdateTask(this));
+        updateTasks.add(new USMClearTablesUpdateTask(this));
+        updateTasks.add(new USMUUIDTablesUpdateTask(this));
+        updateTasks.add(new USMClearTablesUpdateTask93(this));
+        updateTasks.add(new USMTablesUpdateTaskV2(this));
+        updateTasks.add(new USMUUIDTablesUpdateTaskV2(this));
+        // updateTasks.add(new USMClearTablesUpdateTaskV2(this)); // Do not provide this to prevent unnecessary deletion of database content
+        // which would cause slow syncs
+        updateTasks.add(new ChangeCollationUpdateTask(this));
+        updateTasks.add(new USMCreatePrimaryKeyUpdateTask(this));
+        // TODO The next UpdateTask should include code to remove all stored procedures for sequences used throughout USM
+        return updateTasks;
+    }
 
-	public Collection<UpdateTask> getUpdateTasks() {
-		List<UpdateTask> updateTasks = new ArrayList<UpdateTask>();
-		updateTasks.add(new USMTablesUpdateTask(this));
-		updateTasks.add(new USMClearTablesUpdateTask(this));
-		updateTasks.add(new USMUUIDTablesUpdateTask(this));
-		updateTasks.add(new USMClearTablesUpdateTask93(this));
-		updateTasks.add(new USMTablesUpdateTaskV2(this));
-		updateTasks.add(new USMUUIDTablesUpdateTaskV2(this));
-		//		updateTasks.add(new USMClearTablesUpdateTaskV2(this)); // Do not provide this to prevent unnecessary deletion of database content which would cause slow syncs
-		updateTasks.add(new ChangeCollationUpdateTask(this));
-		updateTasks.add(new USMCreatePrimaryKeyUpdateTask(this));
-		// TODO The next UpdateTask should include code to remove all stored procedures for sequences used throughout USM
-		return updateTasks;
-	}
+    public DatabaseService getDatabaseService() {
+        return _service;
+    }
 
-	public DatabaseService getDatabaseService() {
-		return _service;
-	}
-
-	public Log getJournal() {
-		return _journal;
-	}
 }
