@@ -49,11 +49,8 @@
 
 package com.openexchange.groupware.settings.tree.modules.interfaces;
 
-import org.apache.commons.logging.Log;
-import org.osgi.service.component.ComponentContext;
 import com.openexchange.groupware.settings.tree.AbstractModules;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
-import com.openexchange.usm.journal.Journal;
 
 /**
  * Similar class to the one in the eas-project
@@ -62,46 +59,26 @@ import com.openexchange.usm.journal.Journal;
  */
 public class USM_JSON extends AbstractModules {
 
-	/**
-	 * Default constructor.
-	 */
-	public USM_JSON() {
-		super();
-	}
+    /**
+     * Default constructor.
+     */
+    public USM_JSON() {
+        super();
+    }
 
-	/**
-	 * {@inheritDoc}
-	 */
-	public String[] getPath() {
-		return new String[] { "modules", "com.openexchange.usm.json", "module" };
-	}
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public String[] getPath() {
+        return new String[] { "modules", "com.openexchange.usm.json", "module" };
+    }
 
-	/**
-	 * {@inheritDoc}
-	 */
-	@Override
-	protected boolean getModule(final UserConfiguration userConfig) {
-		return false;
-	}
-
-	private Log _journal;
-
-	/*
-	 * (non-Javadoc)
-	 * @see org.osgi.framework.BundleActivator#start(org.osgi.framework.BundleContext)
-	 */
-	public void activate(ComponentContext context) {
-		Journal journal = (Journal) context.locateService(Journal.class.getName());
-		_journal = journal.getLog(USM_JSON.class);
-		_journal.debug("USM_JSON Preferences Item Service activated");
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * @see org.osgi.framework.BundleActivator#stop(org.osgi.framework.BundleContext)
-	 */
-	public void deactivate(ComponentContext context) {
-		_journal.debug("USM_JSON Preferences Item Service deactivated");
-		_journal = null;
-	}
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    protected boolean getModule(final UserConfiguration userConfig) {
+        return false;
+    }
 }
