@@ -49,11 +49,8 @@
 
 package com.openexchange.groupware.settings.tree.modules.interfaces;
 
-import org.apache.commons.logging.Log;
-import org.osgi.service.component.ComponentContext;
 import com.openexchange.groupware.settings.tree.AbstractModules;
 import com.openexchange.groupware.userconfiguration.UserConfiguration;
-import com.openexchange.usm.journal.Journal;
 
 /**
  * Similar class to the one in the eas-project
@@ -62,48 +59,28 @@ import com.openexchange.usm.journal.Journal;
  */
 public class USM_JSONActive extends AbstractModules {
 
-	/**
-	 * Default constructor.
-	 */
-	public USM_JSONActive() {
-		super();
-	}
+    /**
+     * Default constructor.
+     */
+    public USM_JSONActive() {
+        super();
+    }
 
-	/**
-	 * {@inheritDoc}
-	 */
-	public String[] getPath() {
-		return new String[] { "modules", "com.openexchange.usm.json", "active" };
-	}
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    public String[] getPath() {
+        return new String[] { "modules", "com.openexchange.usm.json", "active" };
+    }
 
-	/**
-	 * {@inheritDoc}
-	 */
-	@Override
-	protected boolean getModule(final UserConfiguration userConfig) {
-		return true;
-		// TODO Return specific module activation for USM JSON interface
-		//		return userConfig.hasActiveSync();
-	}
-
-	private Log _journal;
-
-	/*
-	 * (non-Javadoc)
-	 * @see org.osgi.framework.BundleActivator#start(org.osgi.framework.BundleContext)
-	 */
-	public void activate(ComponentContext context) {
-		Journal journal = (Journal) context.locateService(Journal.class.getName());
-		_journal = journal.getLog(USM_JSONActive.class);
-		_journal.info("USM_JSON active Preferences Item Service activated");
-	}
-
-	/*
-	 * (non-Javadoc)
-	 * @see org.osgi.framework.BundleActivator#stop(org.osgi.framework.BundleContext)
-	 */
-	public void deactivate(ComponentContext context) {
-		_journal.info("USM_JSON active Preferences Item Service deactivated");
-		_journal = null;
-	}
+    /**
+     * {@inheritDoc}
+     */
+    @Override
+    protected boolean getModule(final UserConfiguration userConfig) {
+        return true;
+        // TODO Return specific module activation for USM JSON interface
+        // return userConfig.hasActiveSync();
+    }
 }
