@@ -57,9 +57,9 @@ import javax.servlet.http.HttpServletRequest;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-import com.openexchange.usm.api.database.DatabaseAccessException;
+import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.exceptions.USMException;
-import com.openexchange.usm.api.exceptions.USMSQLException;
+import com.openexchange.usm.api.exceptions.USMStorageException;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.json.ConnectorBundleErrorCodes;
@@ -68,7 +68,6 @@ import com.openexchange.usm.json.USMJSONServlet;
 import com.openexchange.usm.json.response.ResponseObject;
 import com.openexchange.usm.json.response.ResponseStatusCode;
 import com.openexchange.usm.session.dataobject.DataObjectSet;
-import com.openexchange.usm.uuid.UUIDMappingBundleErrorCodes;
 
 /**
  * Handler for the USM-invalidateObjects command.
@@ -109,7 +108,7 @@ public class InvalidateObjectsHandler extends NormalCommandHandler {
 					JSONObject response = new JSONObject();
 					response.put("syncid", syncID);
 					response.put("objects", resultData);
-					return new ResponseObject(ResponseStatusCode.BAD_REQUEST, response, UUIDMappingBundleErrorCodes.UUID_DOES_NOT_EXIST, "No object found for UUID " + folderUUID, null, null, e);
+					return new ResponseObject(ResponseStatusCode.BAD_REQUEST, response, ConnectorBundleErrorCodes.UUID_DOES_NOT_EXIST, "No object found for UUID " + folderUUID, null, null, e);
 				}
 			}
 			DataObjectSet objectsSet = new DataObjectSet(objects);
@@ -126,9 +125,9 @@ public class InvalidateObjectsHandler extends NormalCommandHandler {
 			response.put("objects", resultData);
 			logSyncData(" invalidateObjects", folderUUID, syncID, newSyncID, 0L);
 			return new ResponseObject(ResponseStatusCode.SUCCESS, response);
-		} catch (DatabaseAccessException e) {
+		} catch (StorageAccessException e) {
 			throw USMJSONAPIException.createInternalError(ConnectorBundleErrorCodes.INVALIDATE_OBJECTS_DB_ERROR, e);
-		} catch (USMSQLException e) {
+		} catch (USMStorageException e) {
 			throw USMJSONAPIException.createInternalError(ConnectorBundleErrorCodes.INVALIDATE_OBJECTS_SQL_ERROR, e);
 		} catch (JSONException e) {
 			throw USMJSONAPIException.createJSONError(ConnectorBundleErrorCodes.INVALIDATE_OBJECTS_JSON_ERROR, e);
