@@ -48,7 +48,8 @@
  */
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.END_SYNCHRONIZATION;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
 import javax.servlet.http.HttpServletRequest;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.json.ConnectorBundleErrorCodes;
