@@ -48,8 +48,16 @@
  */
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.*;
-import static com.openexchange.usm.json.response.ResponseObject.*;
+import static com.openexchange.usm.connector.commands.CommandConstants.DESTINATIONFOLDERID;
+import static com.openexchange.usm.connector.commands.CommandConstants.DESTINATIONSYNCID;
+import static com.openexchange.usm.connector.commands.CommandConstants.OBJECTIDS;
+import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
+import static com.openexchange.usm.connector.commands.CommandConstants.SOURCEFOLDERID;
+import static com.openexchange.usm.connector.commands.CommandConstants.SOURCESYNCID;
+import static com.openexchange.usm.json.response.ResponseObject.ERROR_DETAILS;
+import static com.openexchange.usm.json.response.ResponseObject.ERROR_MESSAGE;
+import static com.openexchange.usm.json.response.ResponseObject.ERROR_STATUS;
+
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.BitSet;
@@ -57,20 +65,22 @@ import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
+
 import javax.servlet.http.HttpServletRequest;
+
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
-import com.openexchange.usm.api.database.DatabaseAccessException;
+
+import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.exceptions.OperationDeniedException;
 import com.openexchange.usm.api.exceptions.USMException;
-import com.openexchange.usm.api.exceptions.USMSQLException;
-import com.openexchange.usm.api.session.ChangeState;
+import com.openexchange.usm.api.exceptions.USMStorageException;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.Folder;
+import com.openexchange.usm.api.session.assets.ChangeState;
 import com.openexchange.usm.connector.exceptions.DataObjectNotFoundException;
-import com.openexchange.usm.connector.exceptions.InvalidUUIDException;
 import com.openexchange.usm.connector.exceptions.MultipleOperationsOnDataObjectException;
 import com.openexchange.usm.json.ConnectorBundleErrorCodes;
 import com.openexchange.usm.json.USMJSONAPIException;
@@ -79,6 +89,7 @@ import com.openexchange.usm.json.response.ResponseObject;
 import com.openexchange.usm.json.response.ResponseStatusCode;
 import com.openexchange.usm.session.dataobject.DataObjectSet;
 import com.openexchange.usm.util.OXJSONUtil;
+import com.openexchange.usm.util.UUIDToolkit;
 
 /**
  * Handler for the MoveItems USM-JSON-Command.
@@ -211,7 +222,7 @@ public class MoveItemsHandler extends NormalCommandHandler {
             for (int i = 0; i < length; i++) {
                 String uuidString = getString(objectsToMove, i);
                 try {
-                    DataObject object = getDataObjectByUUID(sourceElements, extractUUIDFromString(uuidString));
+                    DataObject object = getDataObjectByUUID(sourceElements, UUIDToolkit.extractUUIDFromString(uuidString));
                     object.getContentType().getTransferHandler().readDataObject(object, _session.getFieldFilter(object.getContentType()));
                     object.commitChanges();
                     object.setParentFolder(destinationFolder);
@@ -221,8 +232,6 @@ public class MoveItemsHandler extends NormalCommandHandler {
                 } catch (MultipleOperationsOnDataObjectException e) {
                     addErrorToMap(uuidString, e.getDataObject(), e, ErrorStatusCode.MULTIPLE_OPERATIONS_ON_SAME_UUID);
                     removeDuplicatesAndAddToError(changesList, uuidString, e);
-                } catch (InvalidUUIDException e) {
-                    addErrorToMap(uuidString, null, e, ErrorStatusCode.UNKNOWN_UUID);
                 } catch (USMException e) {
                     if(isObjectMissingInSourceFolder(e.getOxErrorForJSONResponse()))
                         addErrorToMap(uuidString, null , e, ErrorStatusCode.OBJECT_DOES_NOT_EXIST_IN_SOURCE);
@@ -261,9 +270,9 @@ public class MoveItemsHandler extends NormalCommandHandler {
 				addErrorsToErrorResponse(notmoved, destinationRigths, sourceRights);
 				responseData.put(ERRORS, notmoved);
 			}
-		} catch (USMSQLException e) {
+		} catch (USMStorageException e) {
 			throw USMJSONAPIException.createInternalError(ConnectorBundleErrorCodes.MOVE_ITEMS_INTERNAL_ERROR, e);
-		} catch (DatabaseAccessException e) {
+		} catch (StorageAccessException e) {
 			throw USMJSONAPIException.createInternalError(ConnectorBundleErrorCodes.MOVE_ITEMS_INTERNAL_ERROR_2, e);
 		} catch (USMJSONAPIException e) {
 			throw e;
@@ -378,7 +387,6 @@ public class MoveItemsHandler extends NormalCommandHandler {
 		return ErrorStatusCode.OTHER;
 	}
 
-	
 	@Override
 	protected String[] getOptionalParameters() {
 		return OPTIONAL_PARAMETERS;
