@@ -49,20 +49,7 @@
 
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.ATTACHMENTS;
-import static com.openexchange.usm.connector.commands.CommandConstants.ATTACHMENTS_LAST_MODIFIED;
-import static com.openexchange.usm.connector.commands.CommandConstants.CHANGE_EXCEPTIONS;
-import static com.openexchange.usm.connector.commands.CommandConstants.FOLDER_ID;
-import static com.openexchange.usm.connector.commands.CommandConstants.FOLDER_UUID;
-import static com.openexchange.usm.connector.commands.CommandConstants.IMAGE1;
-import static com.openexchange.usm.connector.commands.CommandConstants.NUMBER_OF_ATTACHMENTS;
-import static com.openexchange.usm.connector.commands.CommandConstants.OBJECT_TYPE;
-import static com.openexchange.usm.connector.commands.CommandConstants.RECURRENCE_ID;
-import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
-import static com.openexchange.usm.connector.commands.CommandConstants.TEMPID;
-import static com.openexchange.usm.connector.commands.CommandConstants.TITLE;
-import static com.openexchange.usm.connector.commands.CommandConstants.TYPE;
-import static com.openexchange.usm.connector.commands.CommandConstants.UUID_KEY;
+import static com.openexchange.usm.connector.commands.CommandConstants.*;
 import static com.openexchange.usm.json.ConnectorBundleErrorCodes.*;
 import static com.openexchange.usm.json.response.ResponseStatusCode.*;
 import java.util.BitSet;
@@ -74,24 +61,24 @@ import javax.servlet.http.HttpServletRequest;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-import com.openexchange.usm.api.contenttypes.ContentType;
-import com.openexchange.usm.api.contenttypes.ContentTypeField;
-import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
-import com.openexchange.usm.api.contenttypes.FolderConstants;
-import com.openexchange.usm.api.contenttypes.FolderContentType;
-import com.openexchange.usm.api.contenttypes.FolderContentTypeTransferHandler;
-import com.openexchange.usm.api.database.DatabaseAccessException;
+import com.openexchange.usm.api.contenttypes.common.CommonConstants;
+import com.openexchange.usm.api.contenttypes.common.ContentType;
+import com.openexchange.usm.api.contenttypes.common.ContentTypeField;
+import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.folder.FolderConstants;
+import com.openexchange.usm.api.contenttypes.folder.FolderContentType;
+import com.openexchange.usm.api.contenttypes.transferhandlers.FolderContentTypeTransferHandler;
+import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.datatypes.DataType;
 import com.openexchange.usm.api.datatypes.PIMAttachment;
 import com.openexchange.usm.api.datatypes.PIMAttachments;
 import com.openexchange.usm.api.exceptions.USMException;
-import com.openexchange.usm.api.exceptions.USMSQLException;
-import com.openexchange.usm.api.session.ChangeState;
+import com.openexchange.usm.api.exceptions.USMStorageException;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.Folder;
-import com.openexchange.usm.api.session.FolderType;
 import com.openexchange.usm.api.session.Session;
-import com.openexchange.usm.contenttypes.util.UtilConstants;
+import com.openexchange.usm.api.session.assets.ChangeState;
+import com.openexchange.usm.api.session.assets.FolderType;
 import com.openexchange.usm.datatypes.contacts.ContactDistributionMember;
 import com.openexchange.usm.datatypes.contacts.Image;
 import com.openexchange.usm.datatypes.tasks.calendar.CommonCalendarTasksFieldNames;
@@ -115,6 +102,9 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
     private static final String OWN_RIGHTS = "own_rights";
 
     protected DataObject[] _allFolders;
+    
+    // Used for MeetingRequests, to only search once for the default calendar folder if there are multiple MeetingRequests to sync
+    protected Folder _defaultCalendarFolder = null;
 
     protected NormalCommandHandler(USMJSONServlet servlet, HttpServletRequest request) throws USMJSONAPIException {
         super(servlet, request);
@@ -131,8 +121,8 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
         return (FolderContentType) _servlet.getContentTypeManager().getContentType(DefaultContentTypes.FOLDER_ID);
     }
 
-	protected void storeExtraFields(ContentType type, BitSet extraFields) throws DatabaseAccessException,
-			USMSQLException {
+	protected void storeExtraFields(ContentType type, BitSet extraFields) throws StorageAccessException,
+			USMStorageException {
         JSONSessionInitializer.storeExtraFields(_session, type, extraFields);
     }
 
@@ -229,9 +219,9 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
                         String user_id = dMember.getUser_id();
                         if (user_id != null) {
                             try {
-                                UUID uuid = o.getSession().getUUID(o.getContentType(), Integer.parseInt(user_id));
-                                if (uuid != null)
-                                    jObj.put(UUID_KEY, uuid.toString());
+                                DataObject cachedListMember = o.getSession().getCachedFolderElement(getDefaultCalendarFolder().getID(), o.getContentType(), user_id);
+                                UUID uuid = cachedListMember != null ? cachedListMember.getUUID() : null;
+                                if (uuid != null) jObj.put(UUID_KEY, uuid.toString());
                             } catch (NumberFormatException ignored) {
                                 // do nothing
                             } catch (USMException ignored) {
@@ -291,16 +281,40 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
         }
         return newObject;
     }
+    
+    protected Folder getDefaultCalendarFolder() throws StorageAccessException, USMStorageException {
+        if (_defaultCalendarFolder == null)
+            _defaultCalendarFolder = determineDefaultCalendarFolder();
+        return _defaultCalendarFolder;
+    }
+
+    private Folder determineDefaultCalendarFolder() throws StorageAccessException, USMStorageException {
+        Folder[] folders = _session.getCachedFolders();
+        for (Folder f : folders) {
+            if (DefaultContentTypes.CALENDAR_ID.equals(f.getElementsContentTypeID())) {
+                Object v = f.getFieldContent(FolderConstants.STANDARD_FOLDER);
+                if (v instanceof Boolean) {
+                    if (((Boolean) v).booleanValue())
+                        return f;
+                } else {
+                    v = f.getFieldContent(FolderConstants.STANDARD_FOLDER_TYPE);
+                    if ((v instanceof Number) && ((Number) v).intValue() == FolderConstants.DEFAULT_CALENDAR_FOLDER)
+                        return f;
+                }
+            }
+        }
+        return null;
+    }
 
     private boolean isParentFolderShared(DataObject o) throws USMJSONAPIException {
         Folder parentFolder = o.getParentFolder();
         if (parentFolder == null)
             try {
                 parentFolder = _session.getCachedFolder(o.getParentFolderID());
-            } catch (DatabaseAccessException e) {
+            } catch (StorageAccessException e) {
 				throw new USMJSONAPIException(ConnectorBundleErrorCodes.COMMAND_DB_ERROR_ON_READ_SHARED_FOLDER,
 						ResponseStatusCode.DATABASE_ERROR, "DB Access Exception on reading shared folder");
-            } catch (USMSQLException e) {
+            } catch (USMStorageException e) {
 				throw new USMJSONAPIException(ConnectorBundleErrorCodes.COMMAND_DB_ERROR_ON_READ_SHARED_FOLDER_1,
 						ResponseStatusCode.DATABASE_ERROR, "SQL Exception on reading shared folder");
             }
@@ -357,14 +371,24 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
         return (o instanceof Number) && ((Number) o).intValue() == 0;
     }
 
-    protected boolean isAppException(DataObject dataObject) {
-        if (dataObject.getContentType().getCode() != DefaultContentTypes.CALENDAR_CODE)
+    public static boolean isAppointmentException(DataObject dataObject) {
+        if(dataObject == null)
+            return false;
+        ContentType contentType = dataObject.getContentType();
+        if (contentType == null || contentType.getCode() != DefaultContentTypes.CALENDAR_CODE)
             return false;
         String id = dataObject.getID();
-		Number recurrence_id = (dataObject.getFieldContent(RECURRENCE_ID) == null) ? null : (Number) (dataObject
-				.getFieldContent(RECURRENCE_ID));
-		return recurrence_id != null && recurrence_id.intValue() != 0 && !id.equals(recurrence_id.toString());
-	}
+        if (!Toolkit.provided(id))
+            return false;
+        Object recurrenceId = dataObject.getFieldContent(RECURRENCE_ID);
+        if (!(recurrenceId instanceof Number))
+            return false;
+        return ((Number) recurrenceId).intValue() != 0 && !id.equals(recurrenceId.toString());
+    }
+
+    protected boolean isAppException(DataObject dataObject) {
+        return isAppointmentException(dataObject);
+    }
 
     protected void addOptionalFolderUUID(DataObject o, JSONObject object) throws USMJSONAPIException, JSONException {
         if (object.has(FOLDER_ID)) {
@@ -379,9 +403,9 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
 			return;
 		try {
 			_allFolders = _session.getCachedFolders();
-		} catch (DatabaseAccessException e) {
+		} catch (StorageAccessException e) {
 			throw generateCantDetermineFolderIDException();
-		} catch (USMSQLException e) {
+		} catch (USMStorageException e) {
 			throw generateCantDetermineFolderIDException();
 		}
 	}
@@ -514,7 +538,7 @@ public abstract class NormalCommandHandler extends BaseCommandHandler {
         if (DefaultContentTypes.MAIL_CODE == object.getContentType().getCode())
             return true; // mails can be only own objects
         int userId = object.getSession().getUserIdentifier();
-        Object createdBy = object.getFieldContent(UtilConstants.CREATED_BY);
+        Object createdBy = object.getFieldContent(CommonConstants.CREATED_BY);
         return (createdBy instanceof String) && createdBy.equals(String.valueOf(userId));
     }
     
