@@ -58,15 +58,15 @@ import javax.servlet.http.HttpServletRequest;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
-import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
-import com.openexchange.usm.api.database.DatabaseAccessException;
+import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
+import com.openexchange.usm.api.database.StorageAccessException;
+import com.openexchange.usm.api.exceptions.InvalidUUIDException;
 import com.openexchange.usm.api.exceptions.USMException;
-import com.openexchange.usm.api.exceptions.USMSQLException;
+import com.openexchange.usm.api.exceptions.USMStorageException;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.api.session.ObjectChanges;
 import com.openexchange.usm.api.session.Session;
-import com.openexchange.usm.api.session.SyncResult;
-import com.openexchange.usm.connector.exceptions.InvalidUUIDException;
+import com.openexchange.usm.api.session.assets.SyncResult;
 import com.openexchange.usm.json.ConnectorBundleErrorCodes;
 import com.openexchange.usm.json.USMJSONAPIException;
 import com.openexchange.usm.json.USMJSONServlet;
@@ -74,17 +74,23 @@ import com.openexchange.usm.json.response.ResponseObject;
 import com.openexchange.usm.json.response.ResponseStatusCode;
 import com.openexchange.usm.session.dataobject.DataObjectSet;
 import com.openexchange.usm.util.JSONToolkit;
+import com.openexchange.usm.util.UUIDToolkit;
 
 /**
  * Handler for the USM-Ping Command.
+ * 
  * @author ldo
  */
 public class PingHandler extends NormalCommandHandler {
 
     private static final String _DEFAULT_INBOX_FOLDER_KEY = "json.DefaultInboxFolder";
 
+    private static final String _LAST_INBOX_CHECK_KEY = "json.LastInboxCheck";
+
     private static final String INTERVAL = "interval";
+
     private static final String[] REQUIRED_PARAMETERS = { SESSIONID };
+
     private static final String[] OPTIONAL_PARAMETERS = { OBJECTIDS };
 
     private DataObjectSet _allCachedFolders;
@@ -98,7 +104,6 @@ public class PingHandler extends NormalCommandHandler {
 
     @Override
     public ResponseObject handleRequest() throws USMJSONAPIException {
-
         JSONArray objectUUIDs = _parameters.has(OBJECTIDS) ? getJSONArray(_parameters, OBJECTIDS) : null;
         try {
             String[] oxIDs = extractOXIdsFromUUIDArray(objectUUIDs);
@@ -109,27 +114,15 @@ public class PingHandler extends NormalCommandHandler {
                 if (changes.hasFolderStructureChanged())
                     resultArray.put(String.valueOf(getSession().getContextUUID()));
             }
-            String inboxId = getDefaultInboxId();
-            if (inboxId != null && !hasDefaultInboxChanges(changes, inboxId)) {
-                if (resultArray == null)
-                    resultArray = new JSONArray();
-                long newestTimestamp = getSession().getNewestTimestamp(inboxId);
-                if (newestTimestamp > 0 && System.currentTimeMillis() - newestTimestamp >= _servlet.getInboxPollingInterval()) {
-                    // clear cached value so that it will be updated from OX configuration
-                    getSession().setCustomProperty(_DEFAULT_INBOX_FOLDER_KEY, null);
-                    Folder defaultInbox = (Folder) getAllCachedFolders().get(inboxId);
-                    if (defaultInbox != null) {
-                        SyncResult syncResult = getSession().syncChangesWithServer(
-                            inboxId,
-                            newestTimestamp,
-                            Session.NO_LIMIT,
-                            null,
-                            false,
-                            null);
-                        if (syncResult.getChanges().length > 0 && defaultInbox.getUUID() != null)
-                            resultArray.put(defaultInbox.getUUID());
-                    }
+            if (shouldPollInbox()) {
+                try {
+                    resultArray = pollInbox(changes, resultArray);
+                } catch (USMException e) {
+                    _servlet.getJournal().warn(
+                        _session + " Error polling Inbox in ping-request, OLOX2-client and/or user mailbox may be misconfigured",
+                        e);
                 }
+                _session.setCustomProperty(_LAST_INBOX_CHECK_KEY, System.currentTimeMillis());
             }
             JSONObject data = new JSONObject();
             if (resultArray != null && resultArray.length() > 0)
@@ -148,7 +141,36 @@ public class PingHandler extends NormalCommandHandler {
         }
     }
 
-    private DataObjectSet getAllCachedFolders() throws DatabaseAccessException, USMSQLException {
+    private boolean shouldPollInbox() {
+        Object o = _session.getCustomProperty(_LAST_INBOX_CHECK_KEY);
+        if (!(o instanceof Long))
+            return true;
+        Long l = (Long) o;
+        return System.currentTimeMillis() > (l + _servlet.getInboxPollingInterval());
+    }
+
+    public JSONArray pollInbox(ObjectChanges changes, JSONArray resultArray) throws USMException {
+        String inboxId = getDefaultInboxId();
+        if (inboxId == null || hasDefaultInboxChanges(changes, inboxId))
+            return resultArray;
+        long newestTimestamp = getSession().getNewestTimestamp(inboxId);
+        if (newestTimestamp <= 0L || System.currentTimeMillis() - newestTimestamp <= _servlet.getInboxPollingInterval())
+            return resultArray;
+        // clear cached value so that it will be updated from OX configuration
+        getSession().setCustomProperty(_DEFAULT_INBOX_FOLDER_KEY, null);
+        Folder defaultInbox = (Folder) getAllCachedFolders().get(inboxId);
+        if (defaultInbox == null || defaultInbox.getUUID() == null)
+            return resultArray;
+        SyncResult syncResult = getSession().syncChangesWithServer(inboxId, newestTimestamp, Session.NO_LIMIT, null, false, null);
+        if (syncResult.getChanges().length == 0)
+            return resultArray;
+        if (resultArray == null)
+            resultArray = new JSONArray();
+        resultArray.put(defaultInbox.getUUID());
+        return resultArray;
+    }
+
+    private DataObjectSet getAllCachedFolders() throws StorageAccessException, USMStorageException {
         if (_allCachedFolders == null) {
             _allCachedFolders = new DataObjectSet(getSession().getCachedFolders());
         }
@@ -178,15 +200,15 @@ public class PingHandler extends NormalCommandHandler {
     private UUID getContextUUID() {
         try {
             return getSession().getContextUUID();
-        } catch (DatabaseAccessException e) {
+        } catch (StorageAccessException e) {
             USMJSONAPIException.createInternalError(ConnectorBundleErrorCodes.PING_NO_DB_ACCESS, e);
-        } catch (USMSQLException e) {
+        } catch (USMStorageException e) {
             USMJSONAPIException.createInternalError(ConnectorBundleErrorCodes.PING_SQL_ERROR, e);
         }
         return null; // not reached
     }
 
-    private String[] extractOXIdsFromUUIDArray(JSONArray jsonArray) throws USMJSONAPIException, InvalidUUIDException, DatabaseAccessException, USMSQLException {
+    private String[] extractOXIdsFromUUIDArray(JSONArray jsonArray) throws USMJSONAPIException, InvalidUUIDException, StorageAccessException, USMStorageException {
         if (jsonArray == null)
             return null;
         int length = jsonArray.length();
@@ -199,7 +221,7 @@ public class PingHandler extends NormalCommandHandler {
                 if (f != null)
                     oxIDs.add(f.getID());
             } else {
-                UUID uuid = extractUUIDFromString(id);
+                UUID uuid = UUIDToolkit.extractUUIDFromString(id);
                 if (uuid.equals(contextUUID)) {
                     _watchFolderHierarchyChanges = true;
                 } else {
@@ -212,7 +234,7 @@ public class PingHandler extends NormalCommandHandler {
         return oxIDs.toArray(new String[oxIDs.size()]);
     }
 
-    private JSONArray toUUIDsJSONArray(String[] idsArray) throws DatabaseAccessException, USMSQLException {
+    private JSONArray toUUIDsJSONArray(String[] idsArray) throws StorageAccessException, USMStorageException {
         DataObjectSet allFolders = getAllCachedFolders();
         JSONArray result = new JSONArray();
         for (int i = 0; i < idsArray.length; i++) {
