@@ -49,10 +49,10 @@
 
 package com.openexchange.usm.connector.sync;
 
-import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
-import com.openexchange.usm.api.session.ChangeState;
+import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.DataObjectFilter;
+import com.openexchange.usm.api.session.assets.ChangeState;
 
 public class EmailSizeFilter implements DataObjectFilter {
 
