@@ -46,63 +46,68 @@
  *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
  *
  */
+
 package com.openexchange.usm.connector.sync;
 
-import com.openexchange.usm.api.session.ChangeState;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.DataObjectFilter;
+import com.openexchange.usm.api.session.assets.ChangeState;
 
 public class PIMAtachmentsCountFilter implements DataObjectFilter {
 
-	private final long _originalSyncID;
+    private final long _originalSyncID;
 
-	private final int _maxCount;
+    private final int _maxCount;
 
-	private boolean _blocked;
+    private boolean _blocked;
 
-	private int _attachmentCount;
+    private int _attachmentCount;
 
-	public PIMAtachmentsCountFilter(long originalSyncID, int maxCount) {
-		_originalSyncID = originalSyncID;
-		_maxCount = maxCount;
-	}
+    public PIMAtachmentsCountFilter(long originalSyncID, int maxCount) {
+        _originalSyncID = originalSyncID;
+        _maxCount = maxCount;
+    }
 
-	public void initialize() {
-		_attachmentCount = 0;
-	}
+    @Override
+    public void initialize() {
+        _attachmentCount = 0;
+    }
 
-	public boolean accept(DataObject object) {
-		return true;
-	}
+    @Override
+    public boolean accept(DataObject object) {
+        return true;
+    }
 
-	public boolean addOperationToResult(ChangeState action, DataObject object) {
-		if (_blocked || object == null)
-			return false;
-		switch (action) {
-			case CREATED:
-			case MODIFIED:
-				int count = getAttachmentCount(object);
-				if (_attachmentCount > 0 && _attachmentCount + count > _maxCount) {
-					_blocked = true;
-					return false;
-				}
-				_attachmentCount += count;
-				return true;
-			default:
-				return true;
-		}
-	}
+    @Override
+    public boolean addOperationToResult(ChangeState action, DataObject object) {
+        if (_blocked || object == null)
+            return false;
+        switch (action) {
+        case CREATED:
+        case MODIFIED:
+            int count = getAttachmentCount(object);
+            if (_attachmentCount > 0 && _attachmentCount + count > _maxCount) {
+                _blocked = true;
+                return false;
+            }
+            _attachmentCount += count;
+            return true;
+        default:
+            return true;
+        }
+    }
 
-	private int getAttachmentCount(DataObject object) {
-		try {
-			Object o = object.getFieldContent("number_of_attachments");
-			return (o instanceof Number) ? ((Number) o).intValue() : 0;
-		} catch (IllegalArgumentException ignored) {
-			return 0;
-		}
-	}
+    private int getAttachmentCount(DataObject object) {
+        try {
+            Object o = object.getFieldContent("number_of_attachments");
+            return (o instanceof Number) ? ((Number) o).intValue() : 0;
+        } catch (IllegalArgumentException ignored) {
+            return 0;
+        }
+    }
 
-	public long getOriginalSyncID() {
-		return _originalSyncID;
-	}
+    @Override
+    public long getOriginalSyncID() {
+        return _originalSyncID;
+    }
 }
