@@ -90,7 +90,6 @@ public interface ConnectorBundleErrorCodes {
 	int COMMAND_SYNC_RESULT_JSON_ERROR = 0x61010D;
 	int COMMAND_SYNC_CONFLICT = 0x61010E;
 	int COMMAND_SYNC_ERROR_JSON_ERROR = 0x61010F;
-	int COMMAND_INVALID_UUID = 0x610110;
 	int COMMAND_NO_JSON_ARRAY_IN_JSON_OBJECT = 0x610111;
 	int COMMAND_NO_JSON_OBJECT_IN_JSON_ARRAY = 0x610112;
 	int COMMAND_NO_STRING_IN_JSON_ARRAY = 0x610113;
@@ -153,6 +152,9 @@ public interface ConnectorBundleErrorCodes {
     int DB_ERROR_WHILE_STORING_PROTOCOL_VERSION = 0x610160;
     int SQL_ERROR_WHILE_STORING_PROTOCOL_VERSION = 0x610161;
     
+    int UUID_RESERVED_FOR_SERVER = 0x610162;
+    int UUID_DOES_NOT_EXIST = 0x610163;
+    
 	// 610200-6102FF: Servlet error codes
 	int SERVLET_REGISTRATION_FAILED = 0x610200;
 	int SERVLET_ALIAS_IN_USE = 0x610201;
@@ -342,5 +344,6 @@ public interface ConnectorBundleErrorCodes {
     int MIMEMAIL_MULTIPLE_SMIME_BODY_FIELDS = 0x618018;
     int SMIMEMAIL_UNSUPPORTED_ENCODING_ERROR = 0x618019;
     int MIMEMAIL_TEMP_FILE_NOT_FOUND_FOR_MAIL_BODY = 0x61801A;
+	
     
 }
