@@ -49,7 +49,7 @@
 
 package com.openexchange.usm.json;
 
-import static com.openexchange.usm.json.ServletConstants.*;
+import static com.openexchange.usm.json.ServletConstants.PROTOCOL;
 import java.io.IOException;
 import java.io.OutputStreamWriter;
 import java.io.Writer;
@@ -62,25 +62,24 @@ import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import org.apache.commons.httpclient.HttpStatus;
 import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.json.JSONException;
 import org.json.JSONObject;
-import org.osgi.service.http.HttpService;
-import org.osgi.service.http.NamespaceException;
-import com.openexchange.usm.api.contenttypes.ContentTypeManager;
+import com.openexchange.usm.api.configuration.ConfigurationManager;
+import com.openexchange.usm.api.configuration.ConfigurationProperties;
+import com.openexchange.usm.api.contenttypes.common.ContentTypeManager;
 import com.openexchange.usm.api.exceptions.TemporaryDownOrBusyException;
 import com.openexchange.usm.api.exceptions.USMException;
+import com.openexchange.usm.api.exceptions.USMInvalidConfigurationException;
 import com.openexchange.usm.api.exceptions.USMJSONException;
 import com.openexchange.usm.api.exceptions.USMResourceAccessException;
 import com.openexchange.usm.api.exceptions.USMStartupException;
+import com.openexchange.usm.api.ox.json.OXJSONPropertyNames;
 import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.api.session.SessionManager;
-import com.openexchange.usm.configuration.ConfigurationManager;
-import com.openexchange.usm.configuration.ConfigurationProperties;
-import com.openexchange.usm.configuration.USMInvalidConfigurationException;
 import com.openexchange.usm.connector.commands.CommandHandler;
 import com.openexchange.usm.json.response.ResponseObject;
 import com.openexchange.usm.json.response.ResponseStatusCode;
-import com.openexchange.usm.ox_json.OXJSONPropertyNames;
 import com.openexchange.usm.util.AccessLimiter;
 
 public class USMJSONServlet extends HttpServlet {
@@ -120,14 +119,10 @@ public class USMJSONServlet extends HttpServlet {
 
     private transient ContentTypeManager _contentTypeManager;
 
-    private transient Log _journal;
-
-    private transient HttpService _httpService;
+    private static final transient Log LOG = LogFactory.getLog(USMJSONServlet.class);
 
     private transient ConfigurationManager _configurationManager;
 
-    private transient String _servletAlias;
-
     private transient long[] _pingTimestamps;
 
     private transient int _pingTimestampsIndex = -1;
@@ -169,17 +164,11 @@ public class USMJSONServlet extends HttpServlet {
      * @param httpService
      * @param configurationManager
      */
-    public void activate(SessionManager sessionManager, ContentTypeManager contentTypeManager, Log log, HttpService httpService, ConfigurationManager configurationManager) {
+    public USMJSONServlet(SessionManager sessionManager, ContentTypeManager contentTypeManager, ConfigurationManager configurationManager) {
         _sessionManager = sessionManager;
         _contentTypeManager = contentTypeManager;
-        _journal = log;
-        _httpService = httpService;
         _configurationManager = configurationManager;
         try {
-            _servletAlias = _configurationManager.getProperty(
-                ConfigurationProperties.JSON_SERVLET_ALIAS_PROPERTY,
-                ConfigurationProperties.JSON_SERVLET_ALIAS_DEFAULT,
-                true);
             _minPingInterval = _configurationManager.getProperty(
                 ConfigurationProperties.JSON_SERVLET_PING_MIN_INTERVAL,
                 ConfigurationProperties.JSON_SERVLET_PING_MIN_INTERVAL_DEFAULT,
@@ -238,47 +227,29 @@ public class USMJSONServlet extends HttpServlet {
                 ConfigurationProperties.JSON_SERVLET_ACCESS_CHECK_REFUSAL_INTERVAL_PROPERTY,
                 ConfigurationProperties.JSON_SERVLET_ACCESS_CHECK_REFUSAL_INTERVAL_DEFAULT,
                 false);
-            _accessLimiter = new AccessLimiter(_journal, testInterval, maxAccesses, refusalInterval);
+            _accessLimiter = new AccessLimiter(LOG, testInterval, maxAccesses, refusalInterval);
         } catch (USMInvalidConfigurationException e1) {
             logAndThrowStartupError(
                 ConnectorBundleErrorCodes.INVALID_ALIAS_FOR_SERVLET,
                 e1.getMessage(),
                 e1);
         }
-
-        try {
-            _httpService.registerServlet(_servletAlias, this, null, _httpService.createDefaultHttpContext());
-            _journal.info("Connector servlet registered under alias " + _servletAlias);
-            _journal.info("Open-Xchange USM/JSON Version " + USMJSONVersion.VERSION + " (Build " + USMJSONVersion.BUILD_NUMBER + ") successfully started");
-        } catch (ServletException e) {
-            logAndThrowStartupError(ConnectorBundleErrorCodes.SERVLET_REGISTRATION_FAILED, "Servlet registration failed", e);
-        } catch (NamespaceException e) {
-            logAndThrowStartupError(ConnectorBundleErrorCodes.SERVLET_ALIAS_IN_USE, "Servlet alias already in use:" + _servletAlias, e);
-        }
     }
 
     private void logAndThrowStartupError(int errorCode, String detailMessage, Throwable cause) {
         String message = "Open-Xchange USM-Connector couldn't be started: " + detailMessage;
-        _journal.error(message, cause);
+        LOG.error(message, cause);
         deactivate();
         throw new USMStartupException(errorCode, message, cause);
     }
 
     /**
-     * unregister http service, set the servlet alias to null
+     * set the servlet alias to null
      */
     public void deactivate() {
-        if (_servletAlias != null) {
-            _httpService.unregister(_servletAlias);
-            _journal.info("Connector servlet unregistered from alias " + _servletAlias);
-            _servletAlias = null;
-        } else {
-            _journal.info("Connector servlet unregistered");
-        }
         _sessionManager = null;
         _contentTypeManager = null;
         _configurationManager = null;
-        _httpService = null;
         // _journal = null; // Do not remove _journal reference to allow logging in other threads to continue as long as possible
         _pingTimestamps = null;
     }
@@ -288,18 +259,18 @@ public class USMJSONServlet extends HttpServlet {
         long startTime = System.currentTimeMillis();
         String command = getCommandName(request);
         Session session = null;
-        if (_journal.isDebugEnabled()) {
-            _journal.debug("HTTP PUT " + command);
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("HTTP PUT " + command);
         }
         try {
             session = handleCommand(request, response, command);
         } catch (Exception error) {
-            _journal.error("Open-Xchange USM/JSON: Internal server error in " + command, error);
+            LOG.error("Open-Xchange USM/JSON: Internal server error in " + command, error);
             sendError(response, HttpStatus.SC_INTERNAL_SERVER_ERROR);
         }
         
-        if (_journal.isDebugEnabled()) {
-            _journal.debug(generateTimeLog(session, command, System.currentTimeMillis() - startTime));
+        if (LOG.isDebugEnabled()) {
+            LOG.debug(generateTimeLog(session, command, System.currentTimeMillis() - startTime));
         }
     }
     
@@ -322,7 +293,7 @@ public class USMJSONServlet extends HttpServlet {
                 e.getMessage(),
                 errorDetailsObject,
                 null);
-            _journal.error(computeLogMessage(command, handler, result), e);
+            LOG.error(computeLogMessage(command, handler, result), e);
             printedError = true;
         } catch (Exception e) {
             JSONObject errorDetailsObject = new JSONObject();
@@ -333,7 +304,7 @@ public class USMJSONServlet extends HttpServlet {
                 e.getMessage(),
                 errorDetailsObject,
                 null);
-            _journal.error(computeLogMessage(command, handler, result), e);
+            LOG.error(computeLogMessage(command, handler, result), e);
             printedError = true;
         }
         if (result != null) {
@@ -376,13 +347,13 @@ public class USMJSONServlet extends HttpServlet {
         case WRONG_MISSING_PARAMETERS:
         case UNSUPPORTED_VERSION:
         case SUCCESS_FILTERED_OUT_LARGE_OBJECTS:
-            if (_journal.isDebugEnabled()) {
+            if (LOG.isDebugEnabled()) {
                 String message = computeLogMessage(command, handler, result);
                 USMJSONException e = result.getCause();
                 if (e instanceof Throwable) {
-                    _journal.debug(message, (Throwable) e);
+                    LOG.debug(message, (Throwable) e);
                 } else {
-                    _journal.debug(message);
+                    LOG.debug(message);
                 }
             }
             break;
@@ -394,12 +365,12 @@ public class USMJSONServlet extends HttpServlet {
                 String message = computeLogMessage(command, handler, result);
                 USMJSONException e = result.getCause();
                 if (e instanceof USMJSONAccessDeniedException) {
-                    _journal.info(result.getErrorMessage());
+                    LOG.info(result.getErrorMessage());
                 } else if (e instanceof Throwable) {
-                    _journal.error(message, (Throwable) e);
+                    LOG.error(message, (Throwable) e);
                 } else {
-                    _journal.error(result.toString(3));
-                    _journal.error(message);
+                    LOG.error(result.toString(3));
+                    LOG.error(message);
                 }
             }
             break;
@@ -486,7 +457,7 @@ public class USMJSONServlet extends HttpServlet {
     }
 
     public Log getJournal() {
-        return _journal;
+        return LOG;
     }
 
     public ConfigurationManager getConfigurationManager() {
