@@ -51,8 +51,9 @@ package com.openexchange.usm.json;
 
 import java.util.ArrayList;
 import java.util.List;
-import com.openexchange.usm.api.database.DatabaseAccessException;
-import com.openexchange.usm.api.exceptions.USMSQLException;
+
+import com.openexchange.usm.api.database.StorageAccessException;
+import com.openexchange.usm.api.exceptions.USMStorageException;
 import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.json.response.ResponseStatusCode;
 import com.openexchange.usm.util.Version;
@@ -68,9 +69,9 @@ public final class USMJSONVersion {
     /**
      * USM JSON versions
      */
-    public static final String VERSION = "7.4.2-12";
+    public static final String VERSION = "7.6.0-10";
 
-    public static final String BUILD_NUMBER = "f559a29e3b5c1e0801a653c473d14fe8063150b2- 6528";
+    public static final String BUILD_NUMBER = "f3131d2a70316e5a9446923793008f4dd0f79645- 6529";
 
     public static final String _CLIENT_USM_JSON_VERSION_KEY = "json.Prot.Version";
 
@@ -129,9 +130,9 @@ public final class USMJSONVersion {
             version = getCurrentVersion();
         try {
             session.setPersistentField(_CLIENT_USM_JSON_VERSION_KEY, version.toString());
-        } catch (DatabaseAccessException e) {
+        } catch (StorageAccessException e) {
             throw USMJSONAPIException.createInternalError(ConnectorBundleErrorCodes.DB_ERROR_WHILE_STORING_PROTOCOL_VERSION, e);
-        } catch (USMSQLException e) {
+        } catch (USMStorageException e) {
             throw USMJSONAPIException.createInternalError(ConnectorBundleErrorCodes.SQL_ERROR_WHILE_STORING_PROTOCOL_VERSION, e);
         }
     }
