@@ -56,8 +56,8 @@ import static com.openexchange.usm.connector.commands.CommandConstants.TEMPID;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
+import com.openexchange.usm.api.contenttypes.common.CommonConstants;
 import com.openexchange.usm.api.session.DataObject;
-import com.openexchange.usm.contenttypes.util.UtilConstants;
 import com.openexchange.usm.util.JSONToolkit;
 
 /**
@@ -72,7 +72,7 @@ public final class MailAttachmentStreamingUtil {
         if (structuredMail.has(ID) && structuredMail.has(DATA_KEY) && structuredMail.has(EXACT_SIZE) && structuredMail.isNull(DATA_KEY) && !structuredMail.has(TEMPID)) {
             try {
                 if (supportsAttachmentStreaming) {
-                    String attachmentId = structuredMail.optString(UtilConstants.ID);
+                    String attachmentId = structuredMail.optString(CommonConstants.ID);
                     long exactSize = structuredMail.optLong(EXACT_SIZE);
                     structuredMail.put(TEMPID, ServerTempId.forMailAttachment(mail, attachmentId, exactSize));
                     structuredMail.remove(DATA_KEY);
