@@ -50,11 +50,11 @@
 package com.openexchange.usm.session.sync;
 
 import java.util.BitSet;
-import com.openexchange.usm.api.contenttypes.OXFolderContent;
-import com.openexchange.usm.api.database.DatabaseAccessException;
+import com.openexchange.usm.api.contenttypes.folder.OXFolderContent;
+import com.openexchange.usm.api.database.StorageAccessException;
 import com.openexchange.usm.api.exceptions.OXCommunicationException;
 import com.openexchange.usm.api.exceptions.USMException;
-import com.openexchange.usm.api.exceptions.USMSQLException;
+import com.openexchange.usm.api.exceptions.USMStorageException;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
@@ -88,6 +88,7 @@ public class FolderElementsStorage implements ContentSyncerStorage {
         _limit = limit;
     }
 
+    @Override
     public boolean getCurrentServerData(DataObjectSet resultSet) throws USMException {
         try {
             OXFolderContent data = readCurrentFolderContent();
@@ -112,10 +113,12 @@ public class FolderElementsStorage implements ContentSyncerStorage {
         return _folder.getElementsContentType().getTransferHandler().readFolderContent(_folder, Math.max(_limit, 0) + 10, _filter);
     }
 
+    @Override
     public long storeServerData(long timestamp, DataObjectSet data, boolean updatesPending) throws USMException {
         return _storeResult ? _session.storeCachedDataObjects(_folder.getID(), _oldTimestamp, timestamp, data, updatesPending) : 0L;
     }
 
+    @Override
     public OXDataCacheID getCacheID() {
         return _cacheID;
     }
@@ -125,6 +128,7 @@ public class FolderElementsStorage implements ContentSyncerStorage {
         return String.valueOf(_session) + ' ' + _folder.getID() + '(' + _storeResult + ')';
     }
 
+    @Override
     public DataObject findMatchingClientObjectForServerObject(DataObjectSet clientDataObjects, DataObject serverObject) {
         return null;
     }
