@@ -57,19 +57,19 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 import java.util.UUID;
-import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
+import com.openexchange.usm.api.contenttypes.common.DefaultContentTypes;
 import com.openexchange.usm.api.exceptions.ConflictingChange;
 import com.openexchange.usm.api.exceptions.ConflictingChangeException;
 import com.openexchange.usm.api.exceptions.InternalUSMException;
 import com.openexchange.usm.api.exceptions.USMException;
-import com.openexchange.usm.api.session.ChangeState;
-import com.openexchange.usm.api.session.ConflictResolution;
 import com.openexchange.usm.api.session.DataObject;
 import com.openexchange.usm.api.session.DataObjectFilter;
 import com.openexchange.usm.api.session.Folder;
-import com.openexchange.usm.api.session.SlowSyncRequiredException;
-import com.openexchange.usm.api.session.SyncResult;
-import com.openexchange.usm.api.session.SynchronizationConflictException;
+import com.openexchange.usm.api.session.assets.ChangeState;
+import com.openexchange.usm.api.session.assets.ConflictResolution;
+import com.openexchange.usm.api.session.assets.SyncResult;
+import com.openexchange.usm.api.session.exceptions.SlowSyncRequiredException;
+import com.openexchange.usm.api.session.exceptions.SynchronizationConflictException;
 import com.openexchange.usm.session.dataobject.DataObjectSet;
 import com.openexchange.usm.session.dataobject.DataObjectUtil;
 import com.openexchange.usm.session.impl.SessionManagerImpl;
