@@ -86,7 +86,7 @@ public class JSONToolkit {
     public static Iterable<String> keys(final JSONObject o) {
         return new Iterable<String>() {
 
-            @SuppressWarnings("unchecked")
+            @Override
             public Iterator<String> iterator() {
                 return o.keys();
             }
